# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Backup"
prefix = "backup"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CopyFromBackupVault = Action("CopyFromBackupVault")
CopyIntoBackupVault = Action("CopyIntoBackupVault")
CreateBackupPlan = Action("CreateBackupPlan")
CreateBackupSelection = Action("CreateBackupSelection")
CreateBackupVault = Action("CreateBackupVault")
CreateFramework = Action("CreateFramework")
CreateReportPlan = Action("CreateReportPlan")
DeleteBackupPlan = Action("DeleteBackupPlan")
DeleteBackupSelection = Action("DeleteBackupSelection")
DeleteBackupVault = Action("DeleteBackupVault")
DeleteBackupVaultAccessPolicy = Action("DeleteBackupVaultAccessPolicy")
DeleteBackupVaultLockConfiguration = Action("DeleteBackupVaultLockConfiguration")
DeleteBackupVaultNotifications = Action("DeleteBackupVaultNotifications")
DeleteFramework = Action("DeleteFramework")
DeleteRecoveryPoint = Action("DeleteRecoveryPoint")
DeleteReportPlan = Action("DeleteReportPlan")
DescribeBackupJob = Action("DescribeBackupJob")
DescribeBackupVault = Action("DescribeBackupVault")
DescribeCopyJob = Action("DescribeCopyJob")
DescribeFramework = Action("DescribeFramework")
DescribeGlobalSettings = Action("DescribeGlobalSettings")
DescribeProtectedResource = Action("DescribeProtectedResource")
DescribeRecoveryPoint = Action("DescribeRecoveryPoint")
DescribeRegionSettings = Action("DescribeRegionSettings")
DescribeReportJob = Action("DescribeReportJob")
DescribeReportPlan = Action("DescribeReportPlan")
DescribeRestoreJob = Action("DescribeRestoreJob")
DisassociateRecoveryPoint = Action("DisassociateRecoveryPoint")
ExportBackupPlanTemplate = Action("ExportBackupPlanTemplate")
GetBackupPlan = Action("GetBackupPlan")
GetBackupPlanFromJSON = Action("GetBackupPlanFromJSON")
GetBackupPlanFromTemplate = Action("GetBackupPlanFromTemplate")
GetBackupSelection = Action("GetBackupSelection")
GetBackupVaultAccessPolicy = Action("GetBackupVaultAccessPolicy")
GetBackupVaultNotifications = Action("GetBackupVaultNotifications")
GetRecoveryPointRestoreMetadata = Action("GetRecoveryPointRestoreMetadata")
GetSupportedResourceTypes = Action("GetSupportedResourceTypes")
ListBackupJobs = Action("ListBackupJobs")
ListBackupPlanTemplates = Action("ListBackupPlanTemplates")
ListBackupPlanVersions = Action("ListBackupPlanVersions")
ListBackupPlans = Action("ListBackupPlans")
ListBackupSelections = Action("ListBackupSelections")
ListBackupVaults = Action("ListBackupVaults")
ListCopyJobs = Action("ListCopyJobs")
ListFrameworks = Action("ListFrameworks")
ListProtectedResources = Action("ListProtectedResources")
ListRecoveryPointsByBackupVault = Action("ListRecoveryPointsByBackupVault")
ListRecoveryPointsByResource = Action("ListRecoveryPointsByResource")
ListReportJobs = Action("ListReportJobs")
ListReportPlans = Action("ListReportPlans")
ListRestoreJobs = Action("ListRestoreJobs")
ListTags = Action("ListTags")
PutBackupVaultAccessPolicy = Action("PutBackupVaultAccessPolicy")
PutBackupVaultLockConfiguration = Action("PutBackupVaultLockConfiguration")
PutBackupVaultNotifications = Action("PutBackupVaultNotifications")
StartBackupJob = Action("StartBackupJob")
StartCopyJob = Action("StartCopyJob")
StartReportJob = Action("StartReportJob")
StartRestoreJob = Action("StartRestoreJob")
StopBackupJob = Action("StopBackupJob")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateBackupPlan = Action("UpdateBackupPlan")
UpdateFramework = Action("UpdateFramework")
UpdateGlobalSettings = Action("UpdateGlobalSettings")
UpdateRecoveryPointLifecycle = Action("UpdateRecoveryPointLifecycle")
UpdateRegionSettings = Action("UpdateRegionSettings")
UpdateReportPlan = Action("UpdateReportPlan")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS BugBust"
prefix = "bugbust"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateEvent = Action("CreateEvent")
EvaluateProfilingGroups = Action("EvaluateProfilingGroups")
GetEvent = Action("GetEvent")
GetJoinEventStatus = Action("GetJoinEventStatus")
JoinEvent = Action("JoinEvent")
ListBugs = Action("ListBugs")
ListEventParticipants = Action("ListEventParticipants")
ListEventScores = Action("ListEventScores")
ListEvents = Action("ListEvents")
ListProfilingGroups = Action("ListProfilingGroups")
ListPullRequests = Action("ListPullRequests")
ListTagsForResource = Action("ListTagsForResource")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateEvent = Action("UpdateEvent")
UpdateWorkItem = Action("UpdateWorkItem")
UpdateWorkItemAdmin = Action("UpdateWorkItemAdmin")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS DeepComposer"
prefix = "deepcomposer"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateCoupon = Action("AssociateCoupon")
CreateAudio = Action("CreateAudio")
CreateComposition = Action("CreateComposition")
CreateModel = Action("CreateModel")
DeleteComposition = Action("DeleteComposition")
DeleteModel = Action("DeleteModel")
GetComposition = Action("GetComposition")
GetModel = Action("GetModel")
GetSampleModel = Action("GetSampleModel")
ListCompositions = Action("ListCompositions")
ListModels = Action("ListModels")
ListSampleModels = Action("ListSampleModels")
ListTagsForResource = Action("ListTagsForResource")
ListTrainingTopics = Action("ListTrainingTopics")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateComposition = Action("UpdateComposition")
UpdateModel = Action("UpdateModel")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon CodeGuru Profiler"
prefix = "codeguru-profiler"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddNotificationChannels = Action("AddNotificationChannels")
BatchGetFrameMetricData = Action("BatchGetFrameMetricData")
ConfigureAgent = Action("ConfigureAgent")
CreateProfilingGroup = Action("CreateProfilingGroup")
DeleteProfilingGroup = Action("DeleteProfilingGroup")
DescribeProfilingGroup = Action("DescribeProfilingGroup")
GetFindingsReportAccountSummary = Action("GetFindingsReportAccountSummary")
GetNotificationConfiguration = Action("GetNotificationConfiguration")
GetPolicy = Action("GetPolicy")
GetProfile = Action("GetProfile")
GetRecommendations = Action("GetRecommendations")
ListFindingsReports = Action("ListFindingsReports")
ListProfileTimes = Action("ListProfileTimes")
ListProfilingGroups = Action("ListProfilingGroups")
ListTagsForResource = Action("ListTagsForResource")
PostAgentProfile = Action("PostAgentProfile")
PutPermission = Action("PutPermission")
RemoveNotificationChannel = Action("RemoveNotificationChannel")
RemovePermission = Action("RemovePermission")
SubmitFeedback = Action("SubmitFeedback")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateProfilingGroup = Action("UpdateProfilingGroup")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Resilience Hub Service"
prefix = "resiliencehub"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddDraftAppVersionResourceMappings = Action("AddDraftAppVersionResourceMappings")
CreateApp = Action("CreateApp")
CreateRecommendationTemplate = Action("CreateRecommendationTemplate")
CreateResiliencyPolicy = Action("CreateResiliencyPolicy")
DeleteApp = Action("DeleteApp")
DeleteAppAssessment = Action("DeleteAppAssessment")
DeleteRecommendationTemplate = Action("DeleteRecommendationTemplate")
DeleteResiliencyPolicy = Action("DeleteResiliencyPolicy")
DescribeApp = Action("DescribeApp")
DescribeAppAssessment = Action("DescribeAppAssessment")
DescribeAppVersionResourcesResolutionStatus = Action(
    "DescribeAppVersionResourcesResolutionStatus"
)
DescribeAppVersionTemplate = Action("DescribeAppVersionTemplate")
DescribeDraftAppVersionResourcesImportStatus = Action(
    "DescribeDraftAppVersionResourcesImportStatus"
)
DescribeResiliencyPolicy = Action("DescribeResiliencyPolicy")
ImportResourcesToDraftAppVersion = Action("ImportResourcesToDraftAppVersion")
ListAlarmRecommendations = Action("ListAlarmRecommendations")
ListAppAssessments = Action("ListAppAssessments")
ListAppComponentCompliances = Action("ListAppComponentCompliances")
ListAppComponentRecommendations = Action("ListAppComponentRecommendations")
ListAppVersionResourceMappings = Action("ListAppVersionResourceMappings")
ListAppVersionResources = Action("ListAppVersionResources")
ListAppVersions = Action("ListAppVersions")
ListApps = Action("ListApps")
ListRecommendationTemplates = Action("ListRecommendationTemplates")
ListResiliencyPolicies = Action("ListResiliencyPolicies")
ListSopRecommendations = Action("ListSopRecommendations")
ListSuggestedResiliencyPolicies = Action("ListSuggestedResiliencyPolicies")
ListTagsForResource = Action("ListTagsForResource")
ListTestRecommendations = Action("ListTestRecommendations")
ListUnsupportedAppVersionResources = Action("ListUnsupportedAppVersionResources")
PublishAppVersion = Action("PublishAppVersion")
PutDraftAppVersionTemplate = Action("PutDraftAppVersionTemplate")
RemoveDraftAppVersionResourceMappings = Action("RemoveDraftAppVersionResourceMappings")
ResolveAppVersionResources = Action("ResolveAppVersionResources")
StartAppAssessment = Action("StartAppAssessment")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateApp = Action("UpdateApp")
UpdateResiliencyPolicy = Action("UpdateResiliencyPolicy")



import unittest

from awacs.helpers.trust import (
    get_application_autoscaling_assumerole_policy,
    get_default_assumerole_policy,
    get_lambda_edge_assumerole_policy,
    make_service_domain_name,
)


def get_policy_services(policy):
    statement = policy.properties["Statement"][0]
    principal = statement.properties["Principal"]
    return principal.data["Service"]


def get_policy_service(policy):
    return get_policy_services(policy)[0]


class TestTrustHelpers(unittest.TestCase):
    def test_make_service_domain_name(self):
        self.assertEqual("ec2.amazonaws.com", make_service_domain_name("ec2"))
        self.assertEqual(
            "ec2.amazonaws.com.cn", make_service_domain_name("ec2", region="cn-north-1")
        )
        # proove function is future proof.
        self.assertEqual(
            "ec2.amazonaws.com", make_service_domain_name("ec2", region="us-east-15")
        )

    def test_get_default_assumerole_policy(self):
        default_policy = get_default_assumerole_policy("us-east-1")
        cn_policy = get_default_assumerole_policy("cn-north-1")

        self.assertEqual(get_policy_service(default_policy), "ec2.amazonaws.com")
        self.assertEqual(get_policy_service(cn_policy), "ec2.amazonaws.com.cn")

    def test_get_application_autoscaling_assumerole_policy(self):
        assumerole_policy = get_application_autoscaling_assumerole_policy()
        self.assertEqual(
            "application-autoscaling.amazonaws.com",
            get_policy_service(assumerole_policy),
        )

    def test_get_lambda_edge_assumerole_policy(self):
        assumerole_policy = get_lambda_edge_assumerole_policy()
        services = get_policy_services(assumerole_policy)
        self.assertEqual(
            services,
            ("lambda.amazonaws.com", "edgelambda.amazonaws.com"),
        )


if __name__ == "__main__":
    unittest.main()



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Elastic Container Service"
prefix = "ecs"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateCapacityProvider = Action("CreateCapacityProvider")
CreateCluster = Action("CreateCluster")
CreateService = Action("CreateService")
CreateTaskSet = Action("CreateTaskSet")
DeleteAccountSetting = Action("DeleteAccountSetting")
DeleteAccountSettings = Action("DeleteAccountSettings")
DeleteAttributes = Action("DeleteAttributes")
DeleteCapacityProvider = Action("DeleteCapacityProvider")
DeleteCluster = Action("DeleteCluster")
DeleteService = Action("DeleteService")
DeleteTaskSet = Action("DeleteTaskSet")
DeregisterContainerInstance = Action("DeregisterContainerInstance")
DeregisterTaskDefinition = Action("DeregisterTaskDefinition")
DescribeCapacityProviders = Action("DescribeCapacityProviders")
DescribeClusters = Action("DescribeClusters")
DescribeContainerInstances = Action("DescribeContainerInstances")
DescribeServices = Action("DescribeServices")
DescribeTaskDefinition = Action("DescribeTaskDefinition")
DescribeTaskSets = Action("DescribeTaskSets")
DescribeTasks = Action("DescribeTasks")
DiscoverPollEndpoint = Action("DiscoverPollEndpoint")
ExecuteCommand = Action("ExecuteCommand")
ListAccountSettings = Action("ListAccountSettings")
ListAttributes = Action("ListAttributes")
ListClusters = Action("ListClusters")
ListContainerInstances = Action("ListContainerInstances")
ListServices = Action("ListServices")
ListTagsForResource = Action("ListTagsForResource")
ListTaskDefinitionFamilies = Action("ListTaskDefinitionFamilies")
ListTaskDefinitions = Action("ListTaskDefinitions")
ListTasks = Action("ListTasks")
Poll = Action("Poll")
PutAccountSetting = Action("PutAccountSetting")
PutAccountSettingDefault = Action("PutAccountSettingDefault")
PutAttributes = Action("PutAttributes")
PutClusterCapacityProviders = Action("PutClusterCapacityProviders")
RegisterContainerInstance = Action("RegisterContainerInstance")
RegisterTaskDefinition = Action("RegisterTaskDefinition")
RunTask = Action("RunTask")
StartTask = Action("StartTask")
StartTelemetrySession = Action("StartTelemetrySession")
StopTask = Action("StopTask")
SubmitAttachmentStateChanges = Action("SubmitAttachmentStateChanges")
SubmitContainerStateChange = Action("SubmitContainerStateChange")
SubmitTaskStateChange = Action("SubmitTaskStateChange")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateCapacityProvider = Action("UpdateCapacityProvider")
UpdateCluster = Action("UpdateCluster")
UpdateClusterSettings = Action("UpdateClusterSettings")
UpdateContainerAgent = Action("UpdateContainerAgent")
UpdateContainerInstancesState = Action("UpdateContainerInstancesState")
UpdateService = Action("UpdateService")
UpdateServicePrimaryTaskSet = Action("UpdateServicePrimaryTaskSet")
UpdateTaskSet = Action("UpdateTaskSet")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Identity Sync"
prefix = "identity-sync"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateSyncFilter = Action("CreateSyncFilter")
CreateSyncProfile = Action("CreateSyncProfile")
CreateSyncTarget = Action("CreateSyncTarget")
DeleteSyncFilter = Action("DeleteSyncFilter")
DeleteSyncProfile = Action("DeleteSyncProfile")
DeleteSyncTarget = Action("DeleteSyncTarget")
GetSyncProfile = Action("GetSyncProfile")
GetSyncTarget = Action("GetSyncTarget")
ListSyncFilters = Action("ListSyncFilters")
StartSync = Action("StartSync")
StopSync = Action("StopSync")
UpdateSyncTarget = Action("UpdateSyncTarget")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Machine Learning"
prefix = "machinelearning"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddTags = Action("AddTags")
CreateBatchPrediction = Action("CreateBatchPrediction")
CreateDataSourceFromRDS = Action("CreateDataSourceFromRDS")
CreateDataSourceFromRedshift = Action("CreateDataSourceFromRedshift")
CreateDataSourceFromS3 = Action("CreateDataSourceFromS3")
CreateEvaluation = Action("CreateEvaluation")
CreateMLModel = Action("CreateMLModel")
CreateRealtimeEndpoint = Action("CreateRealtimeEndpoint")
DeleteBatchPrediction = Action("DeleteBatchPrediction")
DeleteDataSource = Action("DeleteDataSource")
DeleteEvaluation = Action("DeleteEvaluation")
DeleteMLModel = Action("DeleteMLModel")
DeleteRealtimeEndpoint = Action("DeleteRealtimeEndpoint")
DeleteTags = Action("DeleteTags")
DescribeBatchPredictions = Action("DescribeBatchPredictions")
DescribeDataSources = Action("DescribeDataSources")
DescribeEvaluations = Action("DescribeEvaluations")
DescribeMLModels = Action("DescribeMLModels")
DescribeTags = Action("DescribeTags")
GetBatchPrediction = Action("GetBatchPrediction")
GetDataSource = Action("GetDataSource")
GetEvaluation = Action("GetEvaluation")
GetMLModel = Action("GetMLModel")
Predict = Action("Predict")
UpdateBatchPrediction = Action("UpdateBatchPrediction")
UpdateDataSource = Action("UpdateDataSource")
UpdateEvaluation = Action("UpdateEvaluation")
UpdateMLModel = Action("UpdateMLModel")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Elastic Disaster Recovery"
prefix = "drs"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateFailbackClientToRecoveryInstanceForDrs = Action(
    "AssociateFailbackClientToRecoveryInstanceForDrs"
)
BatchCreateVolumeSnapshotGroupForDrs = Action("BatchCreateVolumeSnapshotGroupForDrs")
BatchDeleteSnapshotRequestForDrs = Action("BatchDeleteSnapshotRequestForDrs")
CreateConvertedSnapshotForDrs = Action("CreateConvertedSnapshotForDrs")
CreateExtendedSourceServer = Action("CreateExtendedSourceServer")
CreateRecoveryInstanceForDrs = Action("CreateRecoveryInstanceForDrs")
CreateReplicationConfigurationTemplate = Action(
    "CreateReplicationConfigurationTemplate"
)
CreateSessionForDrs = Action("CreateSessionForDrs")
CreateSourceServerForDrs = Action("CreateSourceServerForDrs")
DeleteJob = Action("DeleteJob")
DeleteRecoveryInstance = Action("DeleteRecoveryInstance")
DeleteReplicationConfigurationTemplate = Action(
    "DeleteReplicationConfigurationTemplate"
)
DeleteSourceServer = Action("DeleteSourceServer")
DescribeJobLogItems = Action("DescribeJobLogItems")
DescribeJobs = Action("DescribeJobs")
DescribeRecoveryInstances = Action("DescribeRecoveryInstances")
DescribeRecoverySnapshots = Action("DescribeRecoverySnapshots")
DescribeReplicationConfigurationTemplates = Action(
    "DescribeReplicationConfigurationTemplates"
)
DescribeReplicationServerAssociationsForDrs = Action(
    "DescribeReplicationServerAssociationsForDrs"
)
DescribeSnapshotRequestsForDrs = Action("DescribeSnapshotRequestsForDrs")
DescribeSourceServers = Action("DescribeSourceServers")
DisconnectRecoveryInstance = Action("DisconnectRecoveryInstance")
DisconnectSourceServer = Action("DisconnectSourceServer")
GetAgentCommandForDrs = Action("GetAgentCommandForDrs")
GetAgentConfirmedResumeInfoForDrs = Action("GetAgentConfirmedResumeInfoForDrs")
GetAgentInstallationAssetsForDrs = Action("GetAgentInstallationAssetsForDrs")
GetAgentReplicationInfoForDrs = Action("GetAgentReplicationInfoForDrs")
GetAgentRuntimeConfigurationForDrs = Action("GetAgentRuntimeConfigurationForDrs")
GetAgentSnapshotCreditsForDrs = Action("GetAgentSnapshotCreditsForDrs")
GetChannelCommandsForDrs = Action("GetChannelCommandsForDrs")
GetFailbackCommandForDrs = Action("GetFailbackCommandForDrs")
GetFailbackLaunchRequestedForDrs = Action("GetFailbackLaunchRequestedForDrs")
GetFailbackReplicationConfiguration = Action("GetFailbackReplicationConfiguration")
GetLaunchConfiguration = Action("GetLaunchConfiguration")
GetReplicationConfiguration = Action("GetReplicationConfiguration")
GetSuggestedFailbackClientDeviceMappingForDrs = Action(
    "GetSuggestedFailbackClientDeviceMappingForDrs"
)
InitializeService = Action("InitializeService")
IssueAgentCertificateForDrs = Action("IssueAgentCertificateForDrs")
ListExtensibleSourceServers = Action("ListExtensibleSourceServers")
ListStagingAccounts = Action("ListStagingAccounts")
ListTagsForResource = Action("ListTagsForResource")
NotifyAgentAuthenticationForDrs = Action("NotifyAgentAuthenticationForDrs")
NotifyAgentConnectedForDrs = Action("NotifyAgentConnectedForDrs")
NotifyAgentDisconnectedForDrs = Action("NotifyAgentDisconnectedForDrs")
NotifyAgentReplicationProgressForDrs = Action("NotifyAgentReplicationProgressForDrs")
NotifyConsistencyAttainedForDrs = Action("NotifyConsistencyAttainedForDrs")
NotifyReplicationServerAuthenticationForDrs = Action(
    "NotifyReplicationServerAuthenticationForDrs"
)
NotifyVolumeEventForDrs = Action("NotifyVolumeEventForDrs")
RetryDataReplication = Action("RetryDataReplication")
SendAgentLogsForDrs = Action("SendAgentLogsForDrs")
SendAgentMetricsForDrs = Action("SendAgentMetricsForDrs")
SendChannelCommandResultForDrs = Action("SendChannelCommandResultForDrs")
SendClientLogsForDrs = Action("SendClientLogsForDrs")
SendClientMetricsForDrs = Action("SendClientMetricsForDrs")
SendVolumeStatsForDrs = Action("SendVolumeStatsForDrs")
StartFailbackLaunch = Action("StartFailbackLaunch")
StartRecovery = Action("StartRecovery")
StopFailback = Action("StopFailback")
TagResource = Action("TagResource")
TerminateRecoveryInstances = Action("TerminateRecoveryInstances")
UntagResource = Action("UntagResource")
UpdateAgentBacklogForDrs = Action("UpdateAgentBacklogForDrs")
UpdateAgentConversionInfoForDrs = Action("UpdateAgentConversionInfoForDrs")
UpdateAgentReplicationInfoForDrs = Action("UpdateAgentReplicationInfoForDrs")
UpdateAgentReplicationProcessStateForDrs = Action(
    "UpdateAgentReplicationProcessStateForDrs"
)
UpdateAgentSourcePropertiesForDrs = Action("UpdateAgentSourcePropertiesForDrs")
UpdateFailbackClientDeviceMappingForDrs = Action(
    "UpdateFailbackClientDeviceMappingForDrs"
)
UpdateFailbackClientLastSeenForDrs = Action("UpdateFailbackClientLastSeenForDrs")
UpdateFailbackReplicationConfiguration = Action(
    "UpdateFailbackReplicationConfiguration"
)
UpdateLaunchConfiguration = Action("UpdateLaunchConfiguration")
UpdateReplicationCertificateForDrs = Action("UpdateReplicationCertificateForDrs")
UpdateReplicationConfiguration = Action("UpdateReplicationConfiguration")
UpdateReplicationConfigurationTemplate = Action(
    "UpdateReplicationConfigurationTemplate"
)



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon GameSparks"
prefix = "gamesparks"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateGame = Action("CreateGame")
CreateSnapshot = Action("CreateSnapshot")
CreateStage = Action("CreateStage")
DeleteGame = Action("DeleteGame")
DeleteStage = Action("DeleteStage")
DisconnectPlayer = Action("DisconnectPlayer")
ExportSnapshot = Action("ExportSnapshot")
GetExtension = Action("GetExtension")
GetExtensionVersion = Action("GetExtensionVersion")
GetGame = Action("GetGame")
GetGameConfiguration = Action("GetGameConfiguration")
GetGeneratedCodeJob = Action("GetGeneratedCodeJob")
GetPlayerConnectionStatus = Action("GetPlayerConnectionStatus")
GetSnapshot = Action("GetSnapshot")
GetStage = Action("GetStage")
GetStageDeployment = Action("GetStageDeployment")
ImportGameConfiguration = Action("ImportGameConfiguration")
InvokeBackend = Action("InvokeBackend")
ListExtensionVersions = Action("ListExtensionVersions")
ListExtensions = Action("ListExtensions")
ListGames = Action("ListGames")
ListGeneratedCodeJobs = Action("ListGeneratedCodeJobs")
ListSnapshots = Action("ListSnapshots")
ListStageDeployments = Action("ListStageDeployments")
ListStages = Action("ListStages")
ListTagsForResource = Action("ListTagsForResource")
StartGeneratedCodeJob = Action("StartGeneratedCodeJob")
StartStageDeployment = Action("StartStageDeployment")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateGame = Action("UpdateGame")
UpdateGameConfiguration = Action("UpdateGameConfiguration")
UpdateSnapshot = Action("UpdateSnapshot")
UpdateStage = Action("UpdateStage")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS License Manager"
prefix = "license-manager"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcceptGrant = Action("AcceptGrant")
CheckInLicense = Action("CheckInLicense")
CheckoutBorrowLicense = Action("CheckoutBorrowLicense")
CheckoutLicense = Action("CheckoutLicense")
CreateGrant = Action("CreateGrant")
CreateGrantVersion = Action("CreateGrantVersion")
CreateLicense = Action("CreateLicense")
CreateLicenseConfiguration = Action("CreateLicenseConfiguration")
CreateLicenseConversionTaskForResource = Action(
    "CreateLicenseConversionTaskForResource"
)
CreateLicenseManagerReportGenerator = Action("CreateLicenseManagerReportGenerator")
CreateLicenseVersion = Action("CreateLicenseVersion")
CreateToken = Action("CreateToken")
DeleteGrant = Action("DeleteGrant")
DeleteLicense = Action("DeleteLicense")
DeleteLicenseConfiguration = Action("DeleteLicenseConfiguration")
DeleteLicenseManagerReportGenerator = Action("DeleteLicenseManagerReportGenerator")
DeleteToken = Action("DeleteToken")
ExtendLicenseConsumption = Action("ExtendLicenseConsumption")
GetAccessToken = Action("GetAccessToken")
GetGrant = Action("GetGrant")
GetLicense = Action("GetLicense")
GetLicenseConfiguration = Action("GetLicenseConfiguration")
GetLicenseConversionTask = Action("GetLicenseConversionTask")
GetLicenseManagerReportGenerator = Action("GetLicenseManagerReportGenerator")
GetLicenseUsage = Action("GetLicenseUsage")
GetServiceSettings = Action("GetServiceSettings")
ListAssociationsForLicenseConfiguration = Action(
    "ListAssociationsForLicenseConfiguration"
)
ListDistributedGrants = Action("ListDistributedGrants")
ListFailuresForLicenseConfigurationOperations = Action(
    "ListFailuresForLicenseConfigurationOperations"
)
ListLicenseConfigurations = Action("ListLicenseConfigurations")
ListLicenseConversionTasks = Action("ListLicenseConversionTasks")
ListLicenseManagerReportGenerators = Action("ListLicenseManagerReportGenerators")
ListLicenseSpecificationsForResource = Action("ListLicenseSpecificationsForResource")
ListLicenseVersions = Action("ListLicenseVersions")
ListLicenses = Action("ListLicenses")
ListReceivedGrants = Action("ListReceivedGrants")
ListReceivedLicenses = Action("ListReceivedLicenses")
ListResourceInventory = Action("ListResourceInventory")
ListTagsForResource = Action("ListTagsForResource")
ListTokens = Action("ListTokens")
ListUsageForLicenseConfiguration = Action("ListUsageForLicenseConfiguration")
RejectGrant = Action("RejectGrant")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateLicenseConfiguration = Action("UpdateLicenseConfiguration")
UpdateLicenseManagerReportGenerator = Action("UpdateLicenseManagerReportGenerator")
UpdateLicenseSpecificationsForResource = Action(
    "UpdateLicenseSpecificationsForResource"
)
UpdateServiceSettings = Action("UpdateServiceSettings")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Chime"
prefix = "chime"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcceptDelegate = Action("AcceptDelegate")
ActivateUsers = Action("ActivateUsers")
AddDomain = Action("AddDomain")
AddOrUpdateGroups = Action("AddOrUpdateGroups")
AssociateChannelFlow = Action("AssociateChannelFlow")
AssociatePhoneNumberWithUser = Action("AssociatePhoneNumberWithUser")
AssociatePhoneNumbersWithVoiceConnector = Action(
    "AssociatePhoneNumbersWithVoiceConnector"
)
AssociatePhoneNumbersWithVoiceConnectorGroup = Action(
    "AssociatePhoneNumbersWithVoiceConnectorGroup"
)
AssociateSigninDelegateGroupsWithAccount = Action(
    "AssociateSigninDelegateGroupsWithAccount"
)
AuthorizeDirectory = Action("AuthorizeDirectory")
BatchCreateAttendee = Action("BatchCreateAttendee")
BatchCreateChannelMembership = Action("BatchCreateChannelMembership")
BatchCreateRoomMembership = Action("BatchCreateRoomMembership")
BatchDeletePhoneNumber = Action("BatchDeletePhoneNumber")
BatchSuspendUser = Action("BatchSuspendUser")
BatchUnsuspendUser = Action("BatchUnsuspendUser")
BatchUpdateAttendeeCapabilitiesExcept = Action("BatchUpdateAttendeeCapabilitiesExcept")
BatchUpdatePhoneNumber = Action("BatchUpdatePhoneNumber")
BatchUpdateUser = Action("BatchUpdateUser")
ChannelFlowCallback = Action("ChannelFlowCallback")
Connect = Action("Connect")
ConnectDirectory = Action("ConnectDirectory")
CreateAccount = Action("CreateAccount")
CreateApiKey = Action("CreateApiKey")
CreateAppInstance = Action("CreateAppInstance")
CreateAppInstanceAdmin = Action("CreateAppInstanceAdmin")
CreateAppInstanceUser = Action("CreateAppInstanceUser")
CreateAttendee = Action("CreateAttendee")
CreateBot = Action("CreateBot")
CreateBotMembership = Action("CreateBotMembership")
CreateCDRBucket = Action("CreateCDRBucket")
CreateChannel = Action("CreateChannel")
CreateChannelBan = Action("CreateChannelBan")
CreateChannelFlow = Action("CreateChannelFlow")
CreateChannelMembership = Action("CreateChannelMembership")
CreateChannelModerator = Action("CreateChannelModerator")
CreateMediaCapturePipeline = Action("CreateMediaCapturePipeline")
CreateMeeting = Action("CreateMeeting")
CreateMeetingDialOut = Action("CreateMeetingDialOut")
CreateMeetingWithAttendees = Action("CreateMeetingWithAttendees")
CreatePhoneNumberOrder = Action("CreatePhoneNumberOrder")
CreateProxySession = Action("CreateProxySession")
CreateRoom = Action("CreateRoom")
CreateRoomMembership = Action("CreateRoomMembership")
CreateSipMediaApplication = Action("CreateSipMediaApplication")
CreateSipMediaApplicationCall = Action("CreateSipMediaApplicationCall")
CreateSipRule = Action("CreateSipRule")
CreateUser = Action("CreateUser")
CreateVoiceConnector = Action("CreateVoiceConnector")
CreateVoiceConnectorGroup = Action("CreateVoiceConnectorGroup")
DeleteAccount = Action("DeleteAccount")
DeleteAccountOpenIdConfig = Action("DeleteAccountOpenIdConfig")
DeleteApiKey = Action("DeleteApiKey")
DeleteAppInstance = Action("DeleteAppInstance")
DeleteAppInstanceAdmin = Action("DeleteAppInstanceAdmin")
DeleteAppInstanceStreamingConfigurations = Action(
    "DeleteAppInstanceStreamingConfigurations"
)
DeleteAppInstanceUser = Action("DeleteAppInstanceUser")
DeleteAttendee = Action("DeleteAttendee")
DeleteCDRBucket = Action("DeleteCDRBucket")
DeleteChannel = Action("DeleteChannel")
DeleteChannelBan = Action("DeleteChannelBan")
DeleteChannelFlow = Action("DeleteChannelFlow")
DeleteChannelMembership = Action("DeleteChannelMembership")
DeleteChannelMessage = Action("DeleteChannelMessage")
DeleteChannelModerator = Action("DeleteChannelModerator")
DeleteDelegate = Action("DeleteDelegate")
DeleteDomain = Action("DeleteDomain")
DeleteEventsConfiguration = Action("DeleteEventsConfiguration")
DeleteGroups = Action("DeleteGroups")
DeleteMediaCapturePipeline = Action("DeleteMediaCapturePipeline")
DeleteMeeting = Action("DeleteMeeting")
DeletePhoneNumber = Action("DeletePhoneNumber")
DeleteProxySession = Action("DeleteProxySession")
DeleteRoom = Action("DeleteRoom")
DeleteRoomMembership = Action("DeleteRoomMembership")
DeleteSipMediaApplication = Action("DeleteSipMediaApplication")
DeleteSipRule = Action("DeleteSipRule")
DeleteVoiceConnector = Action("DeleteVoiceConnector")
DeleteVoiceConnectorEmergencyCallingConfiguration = Action(
    "DeleteVoiceConnectorEmergencyCallingConfiguration"
)
DeleteVoiceConnectorGroup = Action("DeleteVoiceConnectorGroup")
DeleteVoiceConnectorOrigination = Action("DeleteVoiceConnectorOrigination")
DeleteVoiceConnectorProxy = Action("DeleteVoiceConnectorProxy")
DeleteVoiceConnectorStreamingConfiguration = Action(
    "DeleteVoiceConnectorStreamingConfiguration"
)
DeleteVoiceConnectorTermination = Action("DeleteVoiceConnectorTermination")
DeleteVoiceConnectorTerminationCredentials = Action(
    "DeleteVoiceConnectorTerminationCredentials"
)
DeregisterAppInstanceUserEndpoint = Action("DeregisterAppInstanceUserEndpoint")
DescribeAppInstance = Action("DescribeAppInstance")
DescribeAppInstanceAdmin = Action("DescribeAppInstanceAdmin")
DescribeAppInstanceUser = Action("DescribeAppInstanceUser")
DescribeAppInstanceUserEndpoint = Action("DescribeAppInstanceUserEndpoint")
DescribeChannel = Action("DescribeChannel")
DescribeChannelBan = Action("DescribeChannelBan")
DescribeChannelFlow = Action("DescribeChannelFlow")
DescribeChannelMembership = Action("DescribeChannelMembership")
DescribeChannelMembershipForAppInstanceUser = Action(
    "DescribeChannelMembershipForAppInstanceUser"
)
DescribeChannelModeratedByAppInstanceUser = Action(
    "DescribeChannelModeratedByAppInstanceUser"
)
DescribeChannelModerator = Action("DescribeChannelModerator")
DisassociateChannelFlow = Action("DisassociateChannelFlow")
DisassociatePhoneNumberFromUser = Action("DisassociatePhoneNumberFromUser")
DisassociatePhoneNumbersFromVoiceConnector = Action(
    "DisassociatePhoneNumbersFromVoiceConnector"
)
DisassociatePhoneNumbersFromVoiceConnectorGroup = Action(
    "DisassociatePhoneNumbersFromVoiceConnectorGroup"
)
DisassociateSigninDelegateGroupsFromAccount = Action(
    "DisassociateSigninDelegateGroupsFromAccount"
)
DisconnectDirectory = Action("DisconnectDirectory")
GetAccount = Action("GetAccount")
GetAccountResource = Action("GetAccountResource")
GetAccountSettings = Action("GetAccountSettings")
GetAccountWithOpenIdConfig = Action("GetAccountWithOpenIdConfig")
GetAppInstanceRetentionSettings = Action("GetAppInstanceRetentionSettings")
GetAppInstanceStreamingConfigurations = Action("GetAppInstanceStreamingConfigurations")
GetAttendee = Action("GetAttendee")
GetBot = Action("GetBot")
GetCDRBucket = Action("GetCDRBucket")
GetChannelMembershipPreferences = Action("GetChannelMembershipPreferences")
GetChannelMessage = Action("GetChannelMessage")
GetChannelMessageStatus = Action("GetChannelMessageStatus")
GetDomain = Action("GetDomain")
GetEventsConfiguration = Action("GetEventsConfiguration")
GetGlobalSettings = Action("GetGlobalSettings")
GetMediaCapturePipeline = Action("GetMediaCapturePipeline")
GetMeeting = Action("GetMeeting")
GetMeetingDetail = Action("GetMeetingDetail")
GetMessagingSessionEndpoint = Action("GetMessagingSessionEndpoint")
GetPhoneNumber = Action("GetPhoneNumber")
GetPhoneNumberOrder = Action("GetPhoneNumberOrder")
GetPhoneNumberSettings = Action("GetPhoneNumberSettings")
GetProxySession = Action("GetProxySession")
GetRetentionSettings = Action("GetRetentionSettings")
GetRoom = Action("GetRoom")
GetSipMediaApplication = Action("GetSipMediaApplication")
GetSipMediaApplicationLoggingConfiguration = Action(
    "GetSipMediaApplicationLoggingConfiguration"
)
GetSipRule = Action("GetSipRule")
GetTelephonyLimits = Action("GetTelephonyLimits")
GetUser = Action("GetUser")
GetUserActivityReportData = Action("GetUserActivityReportData")
GetUserByEmail = Action("GetUserByEmail")
GetUserSettings = Action("GetUserSettings")
GetVoiceConnector = Action("GetVoiceConnector")
GetVoiceConnectorEmergencyCallingConfiguration = Action(
    "GetVoiceConnectorEmergencyCallingConfiguration"
)
GetVoiceConnectorGroup = Action("GetVoiceConnectorGroup")
GetVoiceConnectorLoggingConfiguration = Action("GetVoiceConnectorLoggingConfiguration")
GetVoiceConnectorOrigination = Action("GetVoiceConnectorOrigination")
GetVoiceConnectorProxy = Action("GetVoiceConnectorProxy")
GetVoiceConnectorStreamingConfiguration = Action(
    "GetVoiceConnectorStreamingConfiguration"
)
GetVoiceConnectorTermination = Action("GetVoiceConnectorTermination")
GetVoiceConnectorTerminationHealth = Action("GetVoiceConnectorTerminationHealth")
InviteDelegate = Action("InviteDelegate")
InviteUsers = Action("InviteUsers")
InviteUsersFromProvider = Action("InviteUsersFromProvider")
ListAccountUsageReportData = Action("ListAccountUsageReportData")
ListAccounts = Action("ListAccounts")
ListApiKeys = Action("ListApiKeys")
ListAppInstanceAdmins = Action("ListAppInstanceAdmins")
ListAppInstanceUserEndpoints = Action("ListAppInstanceUserEndpoints")
ListAppInstanceUsers = Action("ListAppInstanceUsers")
ListAppInstances = Action("ListAppInstances")
ListAttendeeTags = Action("ListAttendeeTags")
ListAttendees = Action("ListAttendees")
ListBots = Action("ListBots")
ListCDRBucket = Action("ListCDRBucket")
ListCallingRegions = Action("ListCallingRegions")
ListChannelBans = Action("ListChannelBans")
ListChannelFlows = Action("ListChannelFlows")
ListChannelMemberships = Action("ListChannelMemberships")
ListChannelMembershipsForAppInstanceUser = Action(
    "ListChannelMembershipsForAppInstanceUser"
)
ListChannelMessages = Action("ListChannelMessages")
ListChannelModerators = Action("ListChannelModerators")
ListChannels = Action("ListChannels")
ListChannelsAssociatedWithChannelFlow = Action("ListChannelsAssociatedWithChannelFlow")
ListChannelsModeratedByAppInstanceUser = Action(
    "ListChannelsModeratedByAppInstanceUser"
)
ListDelegates = Action("ListDelegates")
ListDirectories = Action("ListDirectories")
ListDomains = Action("ListDomains")
ListGroups = Action("ListGroups")
ListMediaCapturePipelines = Action("ListMediaCapturePipelines")
ListMeetingEvents = Action("ListMeetingEvents")
ListMeetingTags = Action("ListMeetingTags")
ListMeetings = Action("ListMeetings")
ListMeetingsReportData = Action("ListMeetingsReportData")
ListPhoneNumberOrders = Action("ListPhoneNumberOrders")
ListPhoneNumbers = Action("ListPhoneNumbers")
ListProxySessions = Action("ListProxySessions")
ListRoomMemberships = Action("ListRoomMemberships")
ListRooms = Action("ListRooms")
ListSipMediaApplications = Action("ListSipMediaApplications")
ListSipRules = Action("ListSipRules")
ListSupportedPhoneNumberCountries = Action("ListSupportedPhoneNumberCountries")
ListTagsForResource = Action("ListTagsForResource")
ListUsers = Action("ListUsers")
ListVoiceConnectorGroups = Action("ListVoiceConnectorGroups")
ListVoiceConnectorTerminationCredentials = Action(
    "ListVoiceConnectorTerminationCredentials"
)
ListVoiceConnectors = Action("ListVoiceConnectors")
LogoutUser = Action("LogoutUser")
PutAppInstanceRetentionSettings = Action("PutAppInstanceRetentionSettings")
PutAppInstanceStreamingConfigurations = Action("PutAppInstanceStreamingConfigurations")
PutChannelMembershipPreferences = Action("PutChannelMembershipPreferences")
PutEventsConfiguration = Action("PutEventsConfiguration")
PutRetentionSettings = Action("PutRetentionSettings")
PutSipMediaApplicationLoggingConfiguration = Action(
    "PutSipMediaApplicationLoggingConfiguration"
)
PutVoiceConnectorEmergencyCallingConfiguration = Action(
    "PutVoiceConnectorEmergencyCallingConfiguration"
)
PutVoiceConnectorLoggingConfiguration = Action("PutVoiceConnectorLoggingConfiguration")
PutVoiceConnectorOrigination = Action("PutVoiceConnectorOrigination")
PutVoiceConnectorProxy = Action("PutVoiceConnectorProxy")
PutVoiceConnectorStreamingConfiguration = Action(
    "PutVoiceConnectorStreamingConfiguration"
)
PutVoiceConnectorTermination = Action("PutVoiceConnectorTermination")
PutVoiceConnectorTerminationCredentials = Action(
    "PutVoiceConnectorTerminationCredentials"
)
RedactChannelMessage = Action("RedactChannelMessage")
RedactConversationMessage = Action("RedactConversationMessage")
RedactRoomMessage = Action("RedactRoomMessage")
RegenerateSecurityToken = Action("RegenerateSecurityToken")
RegisterAppInstanceUserEndpoint = Action("RegisterAppInstanceUserEndpoint")
RenameAccount = Action("RenameAccount")
RenewDelegate = Action("RenewDelegate")
ResetAccountResource = Action("ResetAccountResource")
ResetPersonalPIN = Action("ResetPersonalPIN")
ResetPersonalPin = Action("ResetPersonalPin")
RestorePhoneNumber = Action("RestorePhoneNumber")
RetrieveDataExports = Action("RetrieveDataExports")
SearchAvailablePhoneNumbers = Action("SearchAvailablePhoneNumbers")
SearchChannels = Action("SearchChannels")
SendChannelMessage = Action("SendChannelMessage")
StartDataExport = Action("StartDataExport")
StartMeetingTranscription = Action("StartMeetingTranscription")
StopMeetingTranscription = Action("StopMeetingTranscription")
SubmitSupportRequest = Action("SubmitSupportRequest")
SuspendUsers = Action("SuspendUsers")
TagAttendee = Action("TagAttendee")
TagMeeting = Action("TagMeeting")
TagResource = Action("TagResource")
UnauthorizeDirectory = Action("UnauthorizeDirectory")
UntagAttendee = Action("UntagAttendee")
UntagMeeting = Action("UntagMeeting")
UntagResource = Action("UntagResource")
UpdateAccount = Action("UpdateAccount")
UpdateAccountOpenIdConfig = Action("UpdateAccountOpenIdConfig")
UpdateAccountResource = Action("UpdateAccountResource")
UpdateAccountSettings = Action("UpdateAccountSettings")
UpdateAppInstance = Action("UpdateAppInstance")
UpdateAppInstanceUser = Action("UpdateAppInstanceUser")
UpdateAppInstanceUserEndpoint = Action("UpdateAppInstanceUserEndpoint")
UpdateAttendeeCapabilities = Action("UpdateAttendeeCapabilities")
UpdateBot = Action("UpdateBot")
UpdateCDRBucket = Action("UpdateCDRBucket")
UpdateCDRSettings = Action("UpdateCDRSettings")
UpdateChannel = Action("UpdateChannel")
UpdateChannelFlow = Action("UpdateChannelFlow")
UpdateChannelMessage = Action("UpdateChannelMessage")
UpdateChannelReadMarker = Action("UpdateChannelReadMarker")
UpdateGlobalSettings = Action("UpdateGlobalSettings")
UpdatePhoneNumber = Action("UpdatePhoneNumber")
UpdatePhoneNumberSettings = Action("UpdatePhoneNumberSettings")
UpdateProxySession = Action("UpdateProxySession")
UpdateRoom = Action("UpdateRoom")
UpdateRoomMembership = Action("UpdateRoomMembership")
UpdateSipMediaApplication = Action("UpdateSipMediaApplication")
UpdateSipMediaApplicationCall = Action("UpdateSipMediaApplicationCall")
UpdateSipRule = Action("UpdateSipRule")
UpdateSupportedLicenses = Action("UpdateSupportedLicenses")
UpdateUser = Action("UpdateUser")
UpdateUserLicenses = Action("UpdateUserLicenses")
UpdateUserSettings = Action("UpdateUserSettings")
UpdateVoiceConnector = Action("UpdateVoiceConnector")
UpdateVoiceConnectorGroup = Action("UpdateVoiceConnectorGroup")
ValidateAccountResource = Action("ValidateAccountResource")
ValidateDelegate = Action("ValidateDelegate")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Managed Streaming for Apache Kafka"
prefix = "kafka"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BatchAssociateScramSecret = Action("BatchAssociateScramSecret")
BatchDisassociateScramSecret = Action("BatchDisassociateScramSecret")
CreateCluster = Action("CreateCluster")
CreateClusterV2 = Action("CreateClusterV2")
CreateConfiguration = Action("CreateConfiguration")
DeleteCluster = Action("DeleteCluster")
DeleteConfiguration = Action("DeleteConfiguration")
DescribeCluster = Action("DescribeCluster")
DescribeClusterOperation = Action("DescribeClusterOperation")
DescribeClusterV2 = Action("DescribeClusterV2")
DescribeConfiguration = Action("DescribeConfiguration")
DescribeConfigurationRevision = Action("DescribeConfigurationRevision")
GetBootstrapBrokers = Action("GetBootstrapBrokers")
GetCompatibleKafkaVersions = Action("GetCompatibleKafkaVersions")
ListClusterOperations = Action("ListClusterOperations")
ListClusters = Action("ListClusters")
ListClustersV2 = Action("ListClustersV2")
ListConfigurationRevisions = Action("ListConfigurationRevisions")
ListConfigurations = Action("ListConfigurations")
ListKafkaVersions = Action("ListKafkaVersions")
ListNodes = Action("ListNodes")
ListScramSecrets = Action("ListScramSecrets")
ListTagsForResource = Action("ListTagsForResource")
RebootBroker = Action("RebootBroker")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateBrokerCount = Action("UpdateBrokerCount")
UpdateBrokerStorage = Action("UpdateBrokerStorage")
UpdateBrokerType = Action("UpdateBrokerType")
UpdateClusterConfiguration = Action("UpdateClusterConfiguration")
UpdateClusterKafkaVersion = Action("UpdateClusterKafkaVersion")
UpdateConfiguration = Action("UpdateConfiguration")
UpdateConnectivity = Action("UpdateConnectivity")
UpdateMonitoring = Action("UpdateMonitoring")
UpdateSecurity = Action("UpdateSecurity")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS CodeDeploy"
prefix = "codedeploy"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddTagsToOnPremisesInstances = Action("AddTagsToOnPremisesInstances")
BatchGetApplicationRevisions = Action("BatchGetApplicationRevisions")
BatchGetApplications = Action("BatchGetApplications")
BatchGetDeploymentGroups = Action("BatchGetDeploymentGroups")
BatchGetDeploymentInstances = Action("BatchGetDeploymentInstances")
BatchGetDeploymentTargets = Action("BatchGetDeploymentTargets")
BatchGetDeployments = Action("BatchGetDeployments")
BatchGetOnPremisesInstances = Action("BatchGetOnPremisesInstances")
ContinueDeployment = Action("ContinueDeployment")
CreateApplication = Action("CreateApplication")
CreateCloudFormationDeployment = Action("CreateCloudFormationDeployment")
CreateDeployment = Action("CreateDeployment")
CreateDeploymentConfig = Action("CreateDeploymentConfig")
CreateDeploymentGroup = Action("CreateDeploymentGroup")
DeleteApplication = Action("DeleteApplication")
DeleteDeploymentConfig = Action("DeleteDeploymentConfig")
DeleteDeploymentGroup = Action("DeleteDeploymentGroup")
DeleteGitHubAccountToken = Action("DeleteGitHubAccountToken")
DeleteResourcesByExternalId = Action("DeleteResourcesByExternalId")
DeregisterOnPremisesInstance = Action("DeregisterOnPremisesInstance")
GetApplication = Action("GetApplication")
GetApplicationRevision = Action("GetApplicationRevision")
GetDeployment = Action("GetDeployment")
GetDeploymentConfig = Action("GetDeploymentConfig")
GetDeploymentGroup = Action("GetDeploymentGroup")
GetDeploymentInstance = Action("GetDeploymentInstance")
GetDeploymentTarget = Action("GetDeploymentTarget")
GetOnPremisesInstance = Action("GetOnPremisesInstance")
ListApplicationRevisions = Action("ListApplicationRevisions")
ListApplications = Action("ListApplications")
ListDeploymentConfigs = Action("ListDeploymentConfigs")
ListDeploymentGroups = Action("ListDeploymentGroups")
ListDeploymentInstances = Action("ListDeploymentInstances")
ListDeploymentTargets = Action("ListDeploymentTargets")
ListDeployments = Action("ListDeployments")
ListGitHubAccountTokenNames = Action("ListGitHubAccountTokenNames")
ListOnPremisesInstances = Action("ListOnPremisesInstances")
ListTagsForResource = Action("ListTagsForResource")
PutLifecycleEventHookExecutionStatus = Action("PutLifecycleEventHookExecutionStatus")
RegisterApplicationRevision = Action("RegisterApplicationRevision")
RegisterOnPremisesInstance = Action("RegisterOnPremisesInstance")
RemoveTagsFromOnPremisesInstances = Action("RemoveTagsFromOnPremisesInstances")
SkipWaitTimeForInstanceTermination = Action("SkipWaitTimeForInstanceTermination")
StopDeployment = Action("StopDeployment")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateApplication = Action("UpdateApplication")
UpdateDeploymentGroup = Action("UpdateDeploymentGroup")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Well-Architected Tool"
prefix = "wellarchitected"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateLenses = Action("AssociateLenses")
CreateLensShare = Action("CreateLensShare")
CreateLensVersion = Action("CreateLensVersion")
CreateMilestone = Action("CreateMilestone")
CreateWorkload = Action("CreateWorkload")
CreateWorkloadShare = Action("CreateWorkloadShare")
DeleteLens = Action("DeleteLens")
DeleteLensShare = Action("DeleteLensShare")
DeleteWorkload = Action("DeleteWorkload")
DeleteWorkloadShare = Action("DeleteWorkloadShare")
DisassociateLenses = Action("DisassociateLenses")
ExportLens = Action("ExportLens")
GetAnswer = Action("GetAnswer")
GetLens = Action("GetLens")
GetLensReview = Action("GetLensReview")
GetLensReviewReport = Action("GetLensReviewReport")
GetLensVersionDifference = Action("GetLensVersionDifference")
GetMilestone = Action("GetMilestone")
GetWorkload = Action("GetWorkload")
ImportLens = Action("ImportLens")
ListAnswers = Action("ListAnswers")
ListLensReviewImprovements = Action("ListLensReviewImprovements")
ListLensReviews = Action("ListLensReviews")
ListLensShares = Action("ListLensShares")
ListLenses = Action("ListLenses")
ListMilestones = Action("ListMilestones")
ListNotifications = Action("ListNotifications")
ListShareInvitations = Action("ListShareInvitations")
ListTagsForResource = Action("ListTagsForResource")
ListWorkloadShares = Action("ListWorkloadShares")
ListWorkloads = Action("ListWorkloads")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateAnswer = Action("UpdateAnswer")
UpdateGlobalSettings = Action("UpdateGlobalSettings")
UpdateLensReview = Action("UpdateLensReview")
UpdateShareInvitation = Action("UpdateShareInvitation")
UpdateWorkload = Action("UpdateWorkload")
UpdateWorkloadShare = Action("UpdateWorkloadShare")
UpgradeLensReview = Action("UpgradeLensReview")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Service Catalog"
prefix = "servicecatalog"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcceptPortfolioShare = Action("AcceptPortfolioShare")
AssociateAttributeGroup = Action("AssociateAttributeGroup")
AssociateBudgetWithResource = Action("AssociateBudgetWithResource")
AssociatePrincipalWithPortfolio = Action("AssociatePrincipalWithPortfolio")
AssociateProductWithPortfolio = Action("AssociateProductWithPortfolio")
AssociateResource = Action("AssociateResource")
AssociateServiceActionWithProvisioningArtifact = Action(
    "AssociateServiceActionWithProvisioningArtifact"
)
AssociateTagOptionWithResource = Action("AssociateTagOptionWithResource")
BatchAssociateServiceActionWithProvisioningArtifact = Action(
    "BatchAssociateServiceActionWithProvisioningArtifact"
)
BatchDisassociateServiceActionFromProvisioningArtifact = Action(
    "BatchDisassociateServiceActionFromProvisioningArtifact"
)
CopyProduct = Action("CopyProduct")
CreateApplication = Action("CreateApplication")
CreateAttributeGroup = Action("CreateAttributeGroup")
CreateConstraint = Action("CreateConstraint")
CreatePortfolio = Action("CreatePortfolio")
CreatePortfolioShare = Action("CreatePortfolioShare")
CreateProduct = Action("CreateProduct")
CreateProvisionedProductPlan = Action("CreateProvisionedProductPlan")
CreateProvisioningArtifact = Action("CreateProvisioningArtifact")
CreateServiceAction = Action("CreateServiceAction")
CreateTagOption = Action("CreateTagOption")
DeleteApplication = Action("DeleteApplication")
DeleteAttributeGroup = Action("DeleteAttributeGroup")
DeleteConstraint = Action("DeleteConstraint")
DeletePortfolio = Action("DeletePortfolio")
DeletePortfolioShare = Action("DeletePortfolioShare")
DeleteProduct = Action("DeleteProduct")
DeleteProvisionedProductPlan = Action("DeleteProvisionedProductPlan")
DeleteProvisioningArtifact = Action("DeleteProvisioningArtifact")
DeleteServiceAction = Action("DeleteServiceAction")
DeleteTagOption = Action("DeleteTagOption")
DescribeConstraint = Action("DescribeConstraint")
DescribeCopyProductStatus = Action("DescribeCopyProductStatus")
DescribePortfolio = Action("DescribePortfolio")
DescribePortfolioShareStatus = Action("DescribePortfolioShareStatus")
DescribePortfolioShares = Action("DescribePortfolioShares")
DescribeProduct = Action("DescribeProduct")
DescribeProductAsAdmin = Action("DescribeProductAsAdmin")
DescribeProductView = Action("DescribeProductView")
DescribeProvisionedProduct = Action("DescribeProvisionedProduct")
DescribeProvisionedProductPlan = Action("DescribeProvisionedProductPlan")
DescribeProvisioningArtifact = Action("DescribeProvisioningArtifact")
DescribeProvisioningParameters = Action("DescribeProvisioningParameters")
DescribeRecord = Action("DescribeRecord")
DescribeServiceAction = Action("DescribeServiceAction")
DescribeServiceActionExecutionParameters = Action(
    "DescribeServiceActionExecutionParameters"
)
DescribeTagOption = Action("DescribeTagOption")
DisableAWSOrganizationsAccess = Action("DisableAWSOrganizationsAccess")
DisassociateAttributeGroup = Action("DisassociateAttributeGroup")
DisassociateBudgetFromResource = Action("DisassociateBudgetFromResource")
DisassociatePrincipalFromPortfolio = Action("DisassociatePrincipalFromPortfolio")
DisassociateProductFromPortfolio = Action("DisassociateProductFromPortfolio")
DisassociateResource = Action("DisassociateResource")
DisassociateServiceActionFromProvisioningArtifact = Action(
    "DisassociateServiceActionFromProvisioningArtifact"
)
DisassociateTagOptionFromResource = Action("DisassociateTagOptionFromResource")
EnableAWSOrganizationsAccess = Action("EnableAWSOrganizationsAccess")
ExecuteProvisionedProductPlan = Action("ExecuteProvisionedProductPlan")
ExecuteProvisionedProductServiceAction = Action(
    "ExecuteProvisionedProductServiceAction"
)
GetAWSOrganizationsAccessStatus = Action("GetAWSOrganizationsAccessStatus")
GetApplication = Action("GetApplication")
GetAssociatedResource = Action("GetAssociatedResource")
GetAttributeGroup = Action("GetAttributeGroup")
GetProvisionedProductOutputs = Action("GetProvisionedProductOutputs")
ImportAsProvisionedProduct = Action("ImportAsProvisionedProduct")
ListAcceptedPortfolioShares = Action("ListAcceptedPortfolioShares")
ListApplications = Action("ListApplications")
ListAssociatedAttributeGroups = Action("ListAssociatedAttributeGroups")
ListAssociatedResources = Action("ListAssociatedResources")
ListAttributeGroups = Action("ListAttributeGroups")
ListAttributeGroupsForApplication = Action("ListAttributeGroupsForApplication")
ListBudgetsForResource = Action("ListBudgetsForResource")
ListConstraintsForPortfolio = Action("ListConstraintsForPortfolio")
ListLaunchPaths = Action("ListLaunchPaths")
ListOrganizationPortfolioAccess = Action("ListOrganizationPortfolioAccess")
ListPortfolioAccess = Action("ListPortfolioAccess")
ListPortfolios = Action("ListPortfolios")
ListPortfoliosForProduct = Action("ListPortfoliosForProduct")
ListPrincipalsForPortfolio = Action("ListPrincipalsForPortfolio")
ListProvisionedProductPlans = Action("ListProvisionedProductPlans")
ListProvisioningArtifacts = Action("ListProvisioningArtifacts")
ListProvisioningArtifactsForServiceAction = Action(
    "ListProvisioningArtifactsForServiceAction"
)
ListRecordHistory = Action("ListRecordHistory")
ListResourcesForTagOption = Action("ListResourcesForTagOption")
ListServiceActions = Action("ListServiceActions")
ListServiceActionsForProvisioningArtifact = Action(
    "ListServiceActionsForProvisioningArtifact"
)
ListStackInstancesForProvisionedProduct = Action(
    "ListStackInstancesForProvisionedProduct"
)
ListTagOptions = Action("ListTagOptions")
ListTagsForResource = Action("ListTagsForResource")
ProvisionProduct = Action("ProvisionProduct")
RejectPortfolioShare = Action("RejectPortfolioShare")
ScanProvisionedProducts = Action("ScanProvisionedProducts")
SearchProducts = Action("SearchProducts")
SearchProductsAsAdmin = Action("SearchProductsAsAdmin")
SearchProvisionedProducts = Action("SearchProvisionedProducts")
SyncResource = Action("SyncResource")
TagResource = Action("TagResource")
TerminateProvisionedProduct = Action("TerminateProvisionedProduct")
UntagResource = Action("UntagResource")
UpdateApplication = Action("UpdateApplication")
UpdateAttributeGroup = Action("UpdateAttributeGroup")
UpdateConstraint = Action("UpdateConstraint")
UpdatePortfolio = Action("UpdatePortfolio")
UpdatePortfolioShare = Action("UpdatePortfolioShare")
UpdateProduct = Action("UpdateProduct")
UpdateProvisionedProduct = Action("UpdateProvisionedProduct")
UpdateProvisionedProductProperties = Action("UpdateProvisionedProductProperties")
UpdateProvisioningArtifact = Action("UpdateProvisioningArtifact")
UpdateServiceAction = Action("UpdateServiceAction")
UpdateTagOption = Action("UpdateTagOption")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS IoT Greengrass"
prefix = "greengrass"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateRoleToGroup = Action("AssociateRoleToGroup")
AssociateServiceRoleToAccount = Action("AssociateServiceRoleToAccount")
BatchAssociateClientDeviceWithCoreDevice = Action(
    "BatchAssociateClientDeviceWithCoreDevice"
)
BatchDisassociateClientDeviceFromCoreDevice = Action(
    "BatchDisassociateClientDeviceFromCoreDevice"
)
CancelDeployment = Action("CancelDeployment")
CreateComponentVersion = Action("CreateComponentVersion")
CreateConnectorDefinition = Action("CreateConnectorDefinition")
CreateConnectorDefinitionVersion = Action("CreateConnectorDefinitionVersion")
CreateCoreDefinition = Action("CreateCoreDefinition")
CreateCoreDefinitionVersion = Action("CreateCoreDefinitionVersion")
CreateDeployment = Action("CreateDeployment")
CreateDeviceDefinition = Action("CreateDeviceDefinition")
CreateDeviceDefinitionVersion = Action("CreateDeviceDefinitionVersion")
CreateFunctionDefinition = Action("CreateFunctionDefinition")
CreateFunctionDefinitionVersion = Action("CreateFunctionDefinitionVersion")
CreateGroup = Action("CreateGroup")
CreateGroupCertificateAuthority = Action("CreateGroupCertificateAuthority")
CreateGroupVersion = Action("CreateGroupVersion")
CreateLoggerDefinition = Action("CreateLoggerDefinition")
CreateLoggerDefinitionVersion = Action("CreateLoggerDefinitionVersion")
CreateResourceDefinition = Action("CreateResourceDefinition")
CreateResourceDefinitionVersion = Action("CreateResourceDefinitionVersion")
CreateSoftwareUpdateJob = Action("CreateSoftwareUpdateJob")
CreateSubscriptionDefinition = Action("CreateSubscriptionDefinition")
CreateSubscriptionDefinitionVersion = Action("CreateSubscriptionDefinitionVersion")
DeleteComponent = Action("DeleteComponent")
DeleteConnectorDefinition = Action("DeleteConnectorDefinition")
DeleteCoreDefinition = Action("DeleteCoreDefinition")
DeleteCoreDevice = Action("DeleteCoreDevice")
DeleteDeviceDefinition = Action("DeleteDeviceDefinition")
DeleteFunctionDefinition = Action("DeleteFunctionDefinition")
DeleteGroup = Action("DeleteGroup")
DeleteLoggerDefinition = Action("DeleteLoggerDefinition")
DeleteResourceDefinition = Action("DeleteResourceDefinition")
DeleteSubscriptionDefinition = Action("DeleteSubscriptionDefinition")
DescribeComponent = Action("DescribeComponent")
DisassociateRoleFromGroup = Action("DisassociateRoleFromGroup")
DisassociateServiceRoleFromAccount = Action("DisassociateServiceRoleFromAccount")
Discover = Action("Discover")
GetAssociatedRole = Action("GetAssociatedRole")
GetBulkDeploymentStatus = Action("GetBulkDeploymentStatus")
GetComponent = Action("GetComponent")
GetComponentVersionArtifact = Action("GetComponentVersionArtifact")
GetConnectivityInfo = Action("GetConnectivityInfo")
GetConnectorDefinition = Action("GetConnectorDefinition")
GetConnectorDefinitionVersion = Action("GetConnectorDefinitionVersion")
GetCoreDefinition = Action("GetCoreDefinition")
GetCoreDefinitionVersion = Action("GetCoreDefinitionVersion")
GetCoreDevice = Action("GetCoreDevice")
GetDeployment = Action("GetDeployment")
GetDeploymentStatus = Action("GetDeploymentStatus")
GetDeviceDefinition = Action("GetDeviceDefinition")
GetDeviceDefinitionVersion = Action("GetDeviceDefinitionVersion")
GetFunctionDefinition = Action("GetFunctionDefinition")
GetFunctionDefinitionVersion = Action("GetFunctionDefinitionVersion")
GetGroup = Action("GetGroup")
GetGroupCertificateAuthority = Action("GetGroupCertificateAuthority")
GetGroupCertificateConfiguration = Action("GetGroupCertificateConfiguration")
GetGroupVersion = Action("GetGroupVersion")
GetLoggerDefinition = Action("GetLoggerDefinition")
GetLoggerDefinitionVersion = Action("GetLoggerDefinitionVersion")
GetResourceDefinition = Action("GetResourceDefinition")
GetResourceDefinitionVersion = Action("GetResourceDefinitionVersion")
GetServiceRoleForAccount = Action("GetServiceRoleForAccount")
GetSubscriptionDefinition = Action("GetSubscriptionDefinition")
GetSubscriptionDefinitionVersion = Action("GetSubscriptionDefinitionVersion")
GetThingRuntimeConfiguration = Action("GetThingRuntimeConfiguration")
ListBulkDeploymentDetailedReports = Action("ListBulkDeploymentDetailedReports")
ListBulkDeployments = Action("ListBulkDeployments")
ListClientDevicesAssociatedWithCoreDevice = Action(
    "ListClientDevicesAssociatedWithCoreDevice"
)
ListComponentVersions = Action("ListComponentVersions")
ListComponents = Action("ListComponents")
ListConnectorDefinitionVersions = Action("ListConnectorDefinitionVersions")
ListConnectorDefinitions = Action("ListConnectorDefinitions")
ListCoreDefinitionVersions = Action("ListCoreDefinitionVersions")
ListCoreDefinitions = Action("ListCoreDefinitions")
ListCoreDevices = Action("ListCoreDevices")
ListDeployments = Action("ListDeployments")
ListDeviceDefinitionVersions = Action("ListDeviceDefinitionVersions")
ListDeviceDefinitions = Action("ListDeviceDefinitions")
ListEffectiveDeployments = Action("ListEffectiveDeployments")
ListFunctionDefinitionVersions = Action("ListFunctionDefinitionVersions")
ListFunctionDefinitions = Action("ListFunctionDefinitions")
ListGroupCertificateAuthorities = Action("ListGroupCertificateAuthorities")
ListGroupVersions = Action("ListGroupVersions")
ListGroups = Action("ListGroups")
ListInstalledComponents = Action("ListInstalledComponents")
ListLoggerDefinitionVersions = Action("ListLoggerDefinitionVersions")
ListLoggerDefinitions = Action("ListLoggerDefinitions")
ListResourceDefinitionVersions = Action("ListResourceDefinitionVersions")
ListResourceDefinitions = Action("ListResourceDefinitions")
ListSubscriptionDefinitionVersions = Action("ListSubscriptionDefinitionVersions")
ListSubscriptionDefinitions = Action("ListSubscriptionDefinitions")
ListTagsForResource = Action("ListTagsForResource")
ResetDeployments = Action("ResetDeployments")
ResolveComponentCandidates = Action("ResolveComponentCandidates")
StartBulkDeployment = Action("StartBulkDeployment")
StopBulkDeployment = Action("StopBulkDeployment")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateConnectivityInfo = Action("UpdateConnectivityInfo")
UpdateConnectorDefinition = Action("UpdateConnectorDefinition")
UpdateCoreDefinition = Action("UpdateCoreDefinition")
UpdateDeviceDefinition = Action("UpdateDeviceDefinition")
UpdateFunctionDefinition = Action("UpdateFunctionDefinition")
UpdateGroup = Action("UpdateGroup")
UpdateGroupCertificateConfiguration = Action("UpdateGroupCertificateConfiguration")
UpdateLoggerDefinition = Action("UpdateLoggerDefinition")
UpdateResourceDefinition = Action("UpdateResourceDefinition")
UpdateSubscriptionDefinition = Action("UpdateSubscriptionDefinition")
UpdateThingRuntimeConfiguration = Action("UpdateThingRuntimeConfiguration")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Nimble Studio"
prefix = "nimble"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AcceptEulas = Action("AcceptEulas")
CreateLaunchProfile = Action("CreateLaunchProfile")
CreateStreamingImage = Action("CreateStreamingImage")
CreateStreamingSession = Action("CreateStreamingSession")
CreateStreamingSessionStream = Action("CreateStreamingSessionStream")
CreateStudio = Action("CreateStudio")
CreateStudioComponent = Action("CreateStudioComponent")
DeleteLaunchProfile = Action("DeleteLaunchProfile")
DeleteLaunchProfileMember = Action("DeleteLaunchProfileMember")
DeleteStreamingImage = Action("DeleteStreamingImage")
DeleteStreamingSession = Action("DeleteStreamingSession")
DeleteStudio = Action("DeleteStudio")
DeleteStudioComponent = Action("DeleteStudioComponent")
DeleteStudioMember = Action("DeleteStudioMember")
GetEula = Action("GetEula")
GetFeatureMap = Action("GetFeatureMap")
GetLaunchProfile = Action("GetLaunchProfile")
GetLaunchProfileDetails = Action("GetLaunchProfileDetails")
GetLaunchProfileInitialization = Action("GetLaunchProfileInitialization")
GetLaunchProfileMember = Action("GetLaunchProfileMember")
GetStreamingImage = Action("GetStreamingImage")
GetStreamingSession = Action("GetStreamingSession")
GetStreamingSessionStream = Action("GetStreamingSessionStream")
GetStudio = Action("GetStudio")
GetStudioComponent = Action("GetStudioComponent")
GetStudioMember = Action("GetStudioMember")
ListEulaAcceptances = Action("ListEulaAcceptances")
ListEulas = Action("ListEulas")
ListLaunchProfileMembers = Action("ListLaunchProfileMembers")
ListLaunchProfiles = Action("ListLaunchProfiles")
ListStreamingImages = Action("ListStreamingImages")
ListStreamingSessions = Action("ListStreamingSessions")
ListStudioComponents = Action("ListStudioComponents")
ListStudioMembers = Action("ListStudioMembers")
ListStudios = Action("ListStudios")
ListTagsForResource = Action("ListTagsForResource")
PutLaunchProfileMembers = Action("PutLaunchProfileMembers")
PutStudioLogEvents = Action("PutStudioLogEvents")
PutStudioMembers = Action("PutStudioMembers")
StartStreamingSession = Action("StartStreamingSession")
StartStudioSSOConfigurationRepair = Action("StartStudioSSOConfigurationRepair")
StopStreamingSession = Action("StopStreamingSession")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateLaunchProfile = Action("UpdateLaunchProfile")
UpdateLaunchProfileMember = Action("UpdateLaunchProfileMember")
UpdateStreamingImage = Action("UpdateStreamingImage")
UpdateStudio = Action("UpdateStudio")
UpdateStudioComponent = Action("UpdateStudioComponent")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Service Quotas"
prefix = "servicequotas"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateServiceQuotaTemplate = Action("AssociateServiceQuotaTemplate")
DeleteServiceQuotaIncreaseRequestFromTemplate = Action(
    "DeleteServiceQuotaIncreaseRequestFromTemplate"
)
DisassociateServiceQuotaTemplate = Action("DisassociateServiceQuotaTemplate")
GetAWSDefaultServiceQuota = Action("GetAWSDefaultServiceQuota")
GetAssociationForServiceQuotaTemplate = Action("GetAssociationForServiceQuotaTemplate")
GetRequestedServiceQuotaChange = Action("GetRequestedServiceQuotaChange")
GetServiceQuota = Action("GetServiceQuota")
GetServiceQuotaIncreaseRequestFromTemplate = Action(
    "GetServiceQuotaIncreaseRequestFromTemplate"
)
ListAWSDefaultServiceQuotas = Action("ListAWSDefaultServiceQuotas")
ListRequestedServiceQuotaChangeHistory = Action(
    "ListRequestedServiceQuotaChangeHistory"
)
ListRequestedServiceQuotaChangeHistoryByQuota = Action(
    "ListRequestedServiceQuotaChangeHistoryByQuota"
)
ListServiceQuotaIncreaseRequestsInTemplate = Action(
    "ListServiceQuotaIncreaseRequestsInTemplate"
)
ListServiceQuotas = Action("ListServiceQuotas")
ListServices = Action("ListServices")
ListTagsForResource = Action("ListTagsForResource")
PutServiceQuotaIncreaseRequestIntoTemplate = Action(
    "PutServiceQuotaIncreaseRequestIntoTemplate"
)
RequestServiceQuotaIncrease = Action("RequestServiceQuotaIncrease")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Elastic Transcoder"
prefix = "elastictranscoder"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CancelJob = Action("CancelJob")
CreateJob = Action("CreateJob")
CreatePipeline = Action("CreatePipeline")
CreatePreset = Action("CreatePreset")
DeletePipeline = Action("DeletePipeline")
DeletePreset = Action("DeletePreset")
ListJobsByPipeline = Action("ListJobsByPipeline")
ListJobsByStatus = Action("ListJobsByStatus")
ListPipelines = Action("ListPipelines")
ListPresets = Action("ListPresets")
ReadJob = Action("ReadJob")
ReadPipeline = Action("ReadPipeline")
ReadPreset = Action("ReadPreset")
TestRole = Action("TestRole")
UpdatePipeline = Action("UpdatePipeline")
UpdatePipelineNotifications = Action("UpdatePipelineNotifications")
UpdatePipelineStatus = Action("UpdatePipelineStatus")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS IoT TwinMaker"
prefix = "iottwinmaker"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BatchPutPropertyValues = Action("BatchPutPropertyValues")
CreateComponentType = Action("CreateComponentType")
CreateEntity = Action("CreateEntity")
CreateScene = Action("CreateScene")
CreateWorkspace = Action("CreateWorkspace")
DeleteComponentType = Action("DeleteComponentType")
DeleteEntity = Action("DeleteEntity")
DeleteScene = Action("DeleteScene")
DeleteWorkspace = Action("DeleteWorkspace")
GetComponentType = Action("GetComponentType")
GetEntity = Action("GetEntity")
GetPropertyValue = Action("GetPropertyValue")
GetPropertyValueHistory = Action("GetPropertyValueHistory")
GetScene = Action("GetScene")
GetWorkspace = Action("GetWorkspace")
ListComponentTypes = Action("ListComponentTypes")
ListEntities = Action("ListEntities")
ListScenes = Action("ListScenes")
ListTagsForResource = Action("ListTagsForResource")
ListWorkspaces = Action("ListWorkspaces")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateComponentType = Action("UpdateComponentType")
UpdateEntity = Action("UpdateEntity")
UpdateScene = Action("UpdateScene")
UpdateWorkspace = Action("UpdateWorkspace")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Elastic File System"
prefix = "elasticfilesystem"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


Backup = Action("Backup")
ClientMount = Action("ClientMount")
ClientRootAccess = Action("ClientRootAccess")
ClientWrite = Action("ClientWrite")
CreateAccessPoint = Action("CreateAccessPoint")
CreateFileSystem = Action("CreateFileSystem")
CreateMountTarget = Action("CreateMountTarget")
CreateReplicationConfiguration = Action("CreateReplicationConfiguration")
CreateTags = Action("CreateTags")
DeleteAccessPoint = Action("DeleteAccessPoint")
DeleteFileSystem = Action("DeleteFileSystem")
DeleteFileSystemPolicy = Action("DeleteFileSystemPolicy")
DeleteMountTarget = Action("DeleteMountTarget")
DeleteReplicationConfiguration = Action("DeleteReplicationConfiguration")
DeleteTags = Action("DeleteTags")
DescribeAccessPoints = Action("DescribeAccessPoints")
DescribeAccountPreferences = Action("DescribeAccountPreferences")
DescribeBackupPolicy = Action("DescribeBackupPolicy")
DescribeFileSystemPolicy = Action("DescribeFileSystemPolicy")
DescribeFileSystems = Action("DescribeFileSystems")
DescribeLifecycleConfiguration = Action("DescribeLifecycleConfiguration")
DescribeMountTargetSecurityGroups = Action("DescribeMountTargetSecurityGroups")
DescribeMountTargets = Action("DescribeMountTargets")
DescribeReplicationConfigurations = Action("DescribeReplicationConfigurations")
DescribeTags = Action("DescribeTags")
ListTagsForResource = Action("ListTagsForResource")
ModifyMountTargetSecurityGroups = Action("ModifyMountTargetSecurityGroups")
PutAccountPreferences = Action("PutAccountPreferences")
PutBackupPolicy = Action("PutBackupPolicy")
PutFileSystemPolicy = Action("PutFileSystemPolicy")
PutLifecycleConfiguration = Action("PutLifecycleConfiguration")
Restore = Action("Restore")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateFileSystem = Action("UpdateFileSystem")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon EC2 Image Builder"
prefix = "imagebuilder"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CancelImageCreation = Action("CancelImageCreation")
CreateComponent = Action("CreateComponent")
CreateContainerRecipe = Action("CreateContainerRecipe")
CreateDistributionConfiguration = Action("CreateDistributionConfiguration")
CreateImage = Action("CreateImage")
CreateImagePipeline = Action("CreateImagePipeline")
CreateImageRecipe = Action("CreateImageRecipe")
CreateInfrastructureConfiguration = Action("CreateInfrastructureConfiguration")
DeleteComponent = Action("DeleteComponent")
DeleteContainerRecipe = Action("DeleteContainerRecipe")
DeleteDistributionConfiguration = Action("DeleteDistributionConfiguration")
DeleteImage = Action("DeleteImage")
DeleteImagePipeline = Action("DeleteImagePipeline")
DeleteImageRecipe = Action("DeleteImageRecipe")
DeleteInfrastructureConfiguration = Action("DeleteInfrastructureConfiguration")
GetComponent = Action("GetComponent")
GetComponentPolicy = Action("GetComponentPolicy")
GetContainerRecipe = Action("GetContainerRecipe")
GetContainerRecipePolicy = Action("GetContainerRecipePolicy")
GetDistributionConfiguration = Action("GetDistributionConfiguration")
GetImage = Action("GetImage")
GetImagePipeline = Action("GetImagePipeline")
GetImagePolicy = Action("GetImagePolicy")
GetImageRecipe = Action("GetImageRecipe")
GetImageRecipePolicy = Action("GetImageRecipePolicy")
GetInfrastructureConfiguration = Action("GetInfrastructureConfiguration")
ImportComponent = Action("ImportComponent")
ImportVmImage = Action("ImportVmImage")
ListComponentBuildVersions = Action("ListComponentBuildVersions")
ListComponents = Action("ListComponents")
ListContainerRecipes = Action("ListContainerRecipes")
ListDistributionConfigurations = Action("ListDistributionConfigurations")
ListImageBuildVersions = Action("ListImageBuildVersions")
ListImagePackages = Action("ListImagePackages")
ListImagePipelineImages = Action("ListImagePipelineImages")
ListImagePipelines = Action("ListImagePipelines")
ListImageRecipes = Action("ListImageRecipes")
ListImages = Action("ListImages")
ListInfrastructureConfigurations = Action("ListInfrastructureConfigurations")
ListTagsForResource = Action("ListTagsForResource")
PutComponentPolicy = Action("PutComponentPolicy")
PutContainerRecipePolicy = Action("PutContainerRecipePolicy")
PutImagePolicy = Action("PutImagePolicy")
PutImageRecipePolicy = Action("PutImageRecipePolicy")
StartImagePipelineExecution = Action("StartImagePipelineExecution")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateDistributionConfiguration = Action("UpdateDistributionConfiguration")
UpdateImagePipeline = Action("UpdateImagePipeline")
UpdateInfrastructureConfiguration = Action("UpdateInfrastructureConfiguration")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Billing Conductor"
prefix = "billingconductor"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateAccounts = Action("AssociateAccounts")
AssociatePricingRules = Action("AssociatePricingRules")
BatchAssociateResourcesToCustomLineItem = Action(
    "BatchAssociateResourcesToCustomLineItem"
)
BatchDisassociateResourcesFromCustomLineItem = Action(
    "BatchDisassociateResourcesFromCustomLineItem"
)
CreateBillingGroup = Action("CreateBillingGroup")
CreateCustomLineItem = Action("CreateCustomLineItem")
CreatePricingPlan = Action("CreatePricingPlan")
CreatePricingRule = Action("CreatePricingRule")
DeleteBillingGroup = Action("DeleteBillingGroup")
DeleteCustomLineItem = Action("DeleteCustomLineItem")
DeletePricingPlan = Action("DeletePricingPlan")
DeletePricingRule = Action("DeletePricingRule")
DisassociateAccounts = Action("DisassociateAccounts")
DisassociatePricingRules = Action("DisassociatePricingRules")
ListAccountAssociations = Action("ListAccountAssociations")
ListBillingGroupCostReports = Action("ListBillingGroupCostReports")
ListBillingGroups = Action("ListBillingGroups")
ListCustomLineItems = Action("ListCustomLineItems")
ListPricingPlans = Action("ListPricingPlans")
ListPricingPlansAssociatedWithPricingRule = Action(
    "ListPricingPlansAssociatedWithPricingRule"
)
ListPricingRules = Action("ListPricingRules")
ListPricingRulesAssociatedToPricingPlan = Action(
    "ListPricingRulesAssociatedToPricingPlan"
)
ListResourcesAssociatedToCustomLineItem = Action(
    "ListResourcesAssociatedToCustomLineItem"
)
ListTagsForResource = Action("ListTagsForResource")
ListTagsResource = Action("ListTagsResource")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateBillingGroup = Action("UpdateBillingGroup")
UpdateCustomLineItem = Action("UpdateCustomLineItem")
UpdatePricingPlan = Action("UpdatePricingPlan")
UpdatePricingRule = Action("UpdatePricingRule")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon CodeGuru Reviewer"
prefix = "codeguru-reviewer"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateRepository = Action("AssociateRepository")
CreateCodeReview = Action("CreateCodeReview")
CreateConnectionToken = Action("CreateConnectionToken")
DescribeCodeReview = Action("DescribeCodeReview")
DescribeRecommendationFeedback = Action("DescribeRecommendationFeedback")
DescribeRepositoryAssociation = Action("DescribeRepositoryAssociation")
DisassociateRepository = Action("DisassociateRepository")
GetMetricsData = Action("GetMetricsData")
ListCodeReviews = Action("ListCodeReviews")
ListRecommendationFeedback = Action("ListRecommendationFeedback")
ListRecommendations = Action("ListRecommendations")
ListRepositoryAssociations = Action("ListRepositoryAssociations")
ListTagsForResource = Action("ListTagsForResource")
ListThirdPartyRepositories = Action("ListThirdPartyRepositories")
PutRecommendationFeedback = Action("PutRecommendationFeedback")
TagResource = Action("TagResource")
UnTagResource = Action("UnTagResource")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Managed Service for Prometheus"
prefix = "aps"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateAlertManagerAlerts = Action("CreateAlertManagerAlerts")
CreateAlertManagerDefinition = Action("CreateAlertManagerDefinition")
CreateRuleGroupsNamespace = Action("CreateRuleGroupsNamespace")
CreateWorkspace = Action("CreateWorkspace")
DeleteAlertManagerDefinition = Action("DeleteAlertManagerDefinition")
DeleteAlertManagerSilence = Action("DeleteAlertManagerSilence")
DeleteRuleGroupsNamespace = Action("DeleteRuleGroupsNamespace")
DeleteWorkspace = Action("DeleteWorkspace")
DescribeAlertManagerDefinition = Action("DescribeAlertManagerDefinition")
DescribeRuleGroupsNamespace = Action("DescribeRuleGroupsNamespace")
DescribeWorkspace = Action("DescribeWorkspace")
GetAlertManagerSilence = Action("GetAlertManagerSilence")
GetAlertManagerStatus = Action("GetAlertManagerStatus")
GetLabels = Action("GetLabels")
GetMetricMetadata = Action("GetMetricMetadata")
GetSeries = Action("GetSeries")
ListAlertManagerAlertGroups = Action("ListAlertManagerAlertGroups")
ListAlertManagerAlerts = Action("ListAlertManagerAlerts")
ListAlertManagerReceivers = Action("ListAlertManagerReceivers")
ListAlertManagerSilences = Action("ListAlertManagerSilences")
ListAlerts = Action("ListAlerts")
ListRuleGroupsNamespaces = Action("ListRuleGroupsNamespaces")
ListRules = Action("ListRules")
ListTagsForResource = Action("ListTagsForResource")
ListWorkspaces = Action("ListWorkspaces")
PutAlertManagerDefinition = Action("PutAlertManagerDefinition")
PutAlertManagerSilences = Action("PutAlertManagerSilences")
PutRuleGroupsNamespace = Action("PutRuleGroupsNamespace")
QueryMetrics = Action("QueryMetrics")
RemoteWrite = Action("RemoteWrite")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateWorkspaceAlias = Action("UpdateWorkspaceAlias")



import unittest

from awacs import ec2, iam, s3
from awacs.aws import (
    Action,
    Condition,
    PolicyDocument,
    Statement,
    StringEquals,
    StringLike,
)


class TestEquality(unittest.TestCase):
    def test_condition_equality(self):
        self.assertEqualWithHash(
            Condition(StringLike("s3:prefix", ["home/${aws:username}/*"])),
            Condition(StringLike("s3:prefix", ["home/${aws:username}/*"])),
        )

        self.assertNotEqualWithHash(
            Condition(StringLike("s3:prefix", ["home/${aws:username}/*"])),
            Condition(StringLike("s3:prefix", ["other/${aws:username}/*"])),
        )

        self.assertNotEqualWithHash(
            Condition(StringLike("s3:prefix", ["home/${aws:username}/*"])),
            Condition(StringEquals("s3:prefix", ["home/${aws:username}/*"])),
        )

    def test_arn_equality(self):
        self.assertEqualWithHash(s3.ARN("myBucket"), s3.ARN("myBucket"))

        self.assertNotEqualWithHash(s3.ARN("myBucket"), s3.ARN("myOtherBucket"))

        self.assertEqualWithHash(
            ec2.ARN("some-resource", "some-region", "some-account"),
            ec2.ARN("some-resource", "some-region", "some-account"),
        )

        self.assertNotEqualWithHash(
            ec2.ARN("some-resource", "some-region", "some-account"),
            ec2.ARN("some-resource", "some-other-region", "some-account"),
        )

        self.assertNotEqualWithHash(
            ec2.ARN("some-resource", "some-region", "some-account"),
            iam.ARN("some-resource", "some-region", "some-account"),
        )

    def test_action_equality(self):
        self.assertEqualWithHash(
            Action("autoscaling", "DescribeLaunchConfigurations"),
            Action("autoscaling", "DescribeLaunchConfigurations"),
        )

        self.assertNotEqualWithHash(
            Action("autoscaling", "DescribeLaunchConfigurations"),
            Action("ec2", "DescribeInstances"),
        )

    def test_statement_equality(self):
        one = Statement(
            Effect="Allow",
            Action=[
                Action("autoscaling", "DescribeLaunchConfigurations"),
            ],
            Resource=["*"],
        )
        one_again = Statement(
            Effect="Allow",
            Action=[
                Action("autoscaling", "DescribeLaunchConfigurations"),
            ],
            Resource=["*"],
        )
        two = Statement(
            Effect="Allow",
            Action=[
                Action("ec2", "DescribeInstances"),
            ],
            Resource=["*"],
        )

        self.assertEqualWithHash(one, one_again)
        self.assertNotEqualWithHash(one, two)

    def test_policy_document_equality(self):
        one = PolicyDocument(
            Version="2012-10-17",
            Statement=[
                Statement(
                    Effect="Allow",
                    Action=[
                        Action("autoscaling", "DescribeLaunchConfigurations"),
                    ],
                    Resource=["*"],
                )
            ],
        )
        one_again = PolicyDocument(
            Version="2012-10-17",
            Statement=[
                Statement(
                    Effect="Allow",
                    Action=[
                        Action("autoscaling", "DescribeLaunchConfigurations"),
                    ],
                    Resource=["*"],
                )
            ],
        )

        two = PolicyDocument(
            Version="2012-10-17",
            Statement=[
                Statement(
                    Effect="Allow",
                    Action=[
                        Action("ec2", "DescribeInstances"),
                    ],
                    Resource=["*"],
                )
            ],
        )
        self.assertEqualWithHash(one, one_again)
        self.assertNotEqualWithHash(one, two)

    def assertEqualWithHash(self, one, two):
        self.assertTrue(one == two)
        self.assertEqual(hash(one), hash(two))

    def assertNotEqualWithHash(self, one, two):
        self.assertTrue(one != two)
        self.assertNotEqual(hash(one), hash(two))



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Apache Kafka APIs for Amazon MSK clusters"
prefix = "kafka-cluster"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AlterCluster = Action("AlterCluster")
AlterClusterDynamicConfiguration = Action("AlterClusterDynamicConfiguration")
AlterGroup = Action("AlterGroup")
AlterTopic = Action("AlterTopic")
AlterTopicDynamicConfiguration = Action("AlterTopicDynamicConfiguration")
AlterTransactionalId = Action("AlterTransactionalId")
Connect = Action("Connect")
CreateTopic = Action("CreateTopic")
DeleteGroup = Action("DeleteGroup")
DeleteTopic = Action("DeleteTopic")
DescribeCluster = Action("DescribeCluster")
DescribeClusterDynamicConfiguration = Action("DescribeClusterDynamicConfiguration")
DescribeGroup = Action("DescribeGroup")
DescribeTopic = Action("DescribeTopic")
DescribeTopicDynamicConfiguration = Action("DescribeTopicDynamicConfiguration")
DescribeTransactionalId = Action("DescribeTransactionalId")
ReadData = Action("ReadData")
WriteData = Action("WriteData")
WriteDataIdempotently = Action("WriteDataIdempotently")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Data Exchange"
prefix = "dataexchange"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CancelJob = Action("CancelJob")
CreateAsset = Action("CreateAsset")
CreateDataSet = Action("CreateDataSet")
CreateEventAction = Action("CreateEventAction")
CreateJob = Action("CreateJob")
CreateRevision = Action("CreateRevision")
DeleteAsset = Action("DeleteAsset")
DeleteDataSet = Action("DeleteDataSet")
DeleteEventAction = Action("DeleteEventAction")
DeleteRevision = Action("DeleteRevision")
GetAsset = Action("GetAsset")
GetDataSet = Action("GetDataSet")
GetEventAction = Action("GetEventAction")
GetJob = Action("GetJob")
GetRevision = Action("GetRevision")
ListDataSetRevisions = Action("ListDataSetRevisions")
ListDataSets = Action("ListDataSets")
ListEventActions = Action("ListEventActions")
ListJobs = Action("ListJobs")
ListRevisionAssets = Action("ListRevisionAssets")
ListTagsForResource = Action("ListTagsForResource")
PublishDataSet = Action("PublishDataSet")
RevokeRevision = Action("RevokeRevision")
SendApiAsset = Action("SendApiAsset")
StartJob = Action("StartJob")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateAsset = Action("UpdateAsset")
UpdateDataSet = Action("UpdateDataSet")
UpdateEventAction = Action("UpdateEventAction")
UpdateRevision = Action("UpdateRevision")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Migration Hub Refactor Spaces"
prefix = "refactor-spaces"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateApplication = Action("CreateApplication")
CreateEnvironment = Action("CreateEnvironment")
CreateRoute = Action("CreateRoute")
CreateService = Action("CreateService")
DeleteApplication = Action("DeleteApplication")
DeleteEnvironment = Action("DeleteEnvironment")
DeleteResourcePolicy = Action("DeleteResourcePolicy")
DeleteRoute = Action("DeleteRoute")
DeleteService = Action("DeleteService")
GetApplication = Action("GetApplication")
GetEnvironment = Action("GetEnvironment")
GetResourcePolicy = Action("GetResourcePolicy")
GetRoute = Action("GetRoute")
GetService = Action("GetService")
ListApplications = Action("ListApplications")
ListEnvironmentVpcs = Action("ListEnvironmentVpcs")
ListEnvironments = Action("ListEnvironments")
ListRoutes = Action("ListRoutes")
ListServices = Action("ListServices")
ListTagsForResource = Action("ListTagsForResource")
PutResourcePolicy = Action("PutResourcePolicy")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateRoute = Action("UpdateRoute")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Pinpoint"
prefix = "mobiletargeting"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateApp = Action("CreateApp")
CreateCampaign = Action("CreateCampaign")
CreateEmailTemplate = Action("CreateEmailTemplate")
CreateExportJob = Action("CreateExportJob")
CreateImportJob = Action("CreateImportJob")
CreateInAppTemplate = Action("CreateInAppTemplate")
CreateJourney = Action("CreateJourney")
CreatePushTemplate = Action("CreatePushTemplate")
CreateRecommenderConfiguration = Action("CreateRecommenderConfiguration")
CreateSegment = Action("CreateSegment")
CreateSmsTemplate = Action("CreateSmsTemplate")
CreateVoiceTemplate = Action("CreateVoiceTemplate")
DeleteAdmChannel = Action("DeleteAdmChannel")
DeleteApnsChannel = Action("DeleteApnsChannel")
DeleteApnsSandboxChannel = Action("DeleteApnsSandboxChannel")
DeleteApnsVoipChannel = Action("DeleteApnsVoipChannel")
DeleteApnsVoipSandboxChannel = Action("DeleteApnsVoipSandboxChannel")
DeleteApp = Action("DeleteApp")
DeleteBaiduChannel = Action("DeleteBaiduChannel")
DeleteCampaign = Action("DeleteCampaign")
DeleteEmailChannel = Action("DeleteEmailChannel")
DeleteEmailTemplate = Action("DeleteEmailTemplate")
DeleteEndpoint = Action("DeleteEndpoint")
DeleteEventStream = Action("DeleteEventStream")
DeleteGcmChannel = Action("DeleteGcmChannel")
DeleteInAppTemplate = Action("DeleteInAppTemplate")
DeleteJourney = Action("DeleteJourney")
DeletePushTemplate = Action("DeletePushTemplate")
DeleteRecommenderConfiguration = Action("DeleteRecommenderConfiguration")
DeleteSegment = Action("DeleteSegment")
DeleteSmsChannel = Action("DeleteSmsChannel")
DeleteSmsTemplate = Action("DeleteSmsTemplate")
DeleteUserEndpoints = Action("DeleteUserEndpoints")
DeleteVoiceChannel = Action("DeleteVoiceChannel")
DeleteVoiceTemplate = Action("DeleteVoiceTemplate")
GetAdmChannel = Action("GetAdmChannel")
GetApnsChannel = Action("GetApnsChannel")
GetApnsSandboxChannel = Action("GetApnsSandboxChannel")
GetApnsVoipChannel = Action("GetApnsVoipChannel")
GetApnsVoipSandboxChannel = Action("GetApnsVoipSandboxChannel")
GetApp = Action("GetApp")
GetApplicationDateRangeKpi = Action("GetApplicationDateRangeKpi")
GetApplicationSettings = Action("GetApplicationSettings")
GetApps = Action("GetApps")
GetBaiduChannel = Action("GetBaiduChannel")
GetCampaign = Action("GetCampaign")
GetCampaignActivities = Action("GetCampaignActivities")
GetCampaignDateRangeKpi = Action("GetCampaignDateRangeKpi")
GetCampaignVersion = Action("GetCampaignVersion")
GetCampaignVersions = Action("GetCampaignVersions")
GetCampaigns = Action("GetCampaigns")
GetChannels = Action("GetChannels")
GetEmailChannel = Action("GetEmailChannel")
GetEmailTemplate = Action("GetEmailTemplate")
GetEndpoint = Action("GetEndpoint")
GetEventStream = Action("GetEventStream")
GetExportJob = Action("GetExportJob")
GetExportJobs = Action("GetExportJobs")
GetGcmChannel = Action("GetGcmChannel")
GetImportJob = Action("GetImportJob")
GetImportJobs = Action("GetImportJobs")
GetInAppMessages = Action("GetInAppMessages")
GetInAppTemplate = Action("GetInAppTemplate")
GetJourney = Action("GetJourney")
GetJourneyDateRangeKpi = Action("GetJourneyDateRangeKpi")
GetJourneyExecutionActivityMetrics = Action("GetJourneyExecutionActivityMetrics")
GetJourneyExecutionMetrics = Action("GetJourneyExecutionMetrics")
GetPushTemplate = Action("GetPushTemplate")
GetRecommenderConfiguration = Action("GetRecommenderConfiguration")
GetRecommenderConfigurations = Action("GetRecommenderConfigurations")
GetReports = Action("GetReports")
GetSegment = Action("GetSegment")
GetSegmentExportJobs = Action("GetSegmentExportJobs")
GetSegmentImportJobs = Action("GetSegmentImportJobs")
GetSegmentVersion = Action("GetSegmentVersion")
GetSegmentVersions = Action("GetSegmentVersions")
GetSegments = Action("GetSegments")
GetSmsChannel = Action("GetSmsChannel")
GetSmsTemplate = Action("GetSmsTemplate")
GetUserEndpoints = Action("GetUserEndpoints")
GetVoiceChannel = Action("GetVoiceChannel")
GetVoiceTemplate = Action("GetVoiceTemplate")
ListJourneys = Action("ListJourneys")
ListTagsForResource = Action("ListTagsForResource")
ListTemplateVersions = Action("ListTemplateVersions")
ListTemplates = Action("ListTemplates")
PhoneNumberValidate = Action("PhoneNumberValidate")
PutEventStream = Action("PutEventStream")
PutEvents = Action("PutEvents")
RemoveAttributes = Action("RemoveAttributes")
SendMessages = Action("SendMessages")
SendOTPMessage = Action("SendOTPMessage")
SendUsersMessages = Action("SendUsersMessages")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateAdmChannel = Action("UpdateAdmChannel")
UpdateApnsChannel = Action("UpdateApnsChannel")
UpdateApnsSandboxChannel = Action("UpdateApnsSandboxChannel")
UpdateApnsVoipChannel = Action("UpdateApnsVoipChannel")
UpdateApnsVoipSandboxChannel = Action("UpdateApnsVoipSandboxChannel")
UpdateApplicationSettings = Action("UpdateApplicationSettings")
UpdateBaiduChannel = Action("UpdateBaiduChannel")
UpdateCampaign = Action("UpdateCampaign")
UpdateEmailChannel = Action("UpdateEmailChannel")
UpdateEmailTemplate = Action("UpdateEmailTemplate")
UpdateEndpoint = Action("UpdateEndpoint")
UpdateEndpointsBatch = Action("UpdateEndpointsBatch")
UpdateGcmChannel = Action("UpdateGcmChannel")
UpdateInAppTemplate = Action("UpdateInAppTemplate")
UpdateJourney = Action("UpdateJourney")
UpdateJourneyState = Action("UpdateJourneyState")
UpdatePushTemplate = Action("UpdatePushTemplate")
UpdateRecommenderConfiguration = Action("UpdateRecommenderConfiguration")
UpdateSegment = Action("UpdateSegment")
UpdateSmsChannel = Action("UpdateSmsChannel")
UpdateSmsTemplate = Action("UpdateSmsTemplate")
UpdateTemplateActiveVersion = Action("UpdateTemplateActiveVersion")
UpdateVoiceChannel = Action("UpdateVoiceChannel")
UpdateVoiceTemplate = Action("UpdateVoiceTemplate")
VerifyOTPMessage = Action("VerifyOTPMessage")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Amplify UI Builder"
prefix = "amplifyuibuilder"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateComponent = Action("CreateComponent")
CreateTheme = Action("CreateTheme")
DeleteComponent = Action("DeleteComponent")
DeleteTheme = Action("DeleteTheme")
ExchangeCodeForToken = Action("ExchangeCodeForToken")
ExportComponents = Action("ExportComponents")
ExportThemes = Action("ExportThemes")
GetComponent = Action("GetComponent")
GetTheme = Action("GetTheme")
ListComponents = Action("ListComponents")
ListTagsForResource = Action("ListTagsForResource")
ListThemes = Action("ListThemes")
RefreshToken = Action("RefreshToken")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateComponent = Action("UpdateComponent")
UpdateTheme = Action("UpdateTheme")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS RoboMaker"
prefix = "robomaker"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


BatchDeleteWorlds = Action("BatchDeleteWorlds")
BatchDescribeSimulationJob = Action("BatchDescribeSimulationJob")
CancelDeploymentJob = Action("CancelDeploymentJob")
CancelSimulationJob = Action("CancelSimulationJob")
CancelSimulationJobBatch = Action("CancelSimulationJobBatch")
CancelWorldExportJob = Action("CancelWorldExportJob")
CancelWorldGenerationJob = Action("CancelWorldGenerationJob")
CreateDeploymentJob = Action("CreateDeploymentJob")
CreateFleet = Action("CreateFleet")
CreateRobot = Action("CreateRobot")
CreateRobotApplication = Action("CreateRobotApplication")
CreateRobotApplicationVersion = Action("CreateRobotApplicationVersion")
CreateSimulationApplication = Action("CreateSimulationApplication")
CreateSimulationApplicationVersion = Action("CreateSimulationApplicationVersion")
CreateSimulationJob = Action("CreateSimulationJob")
CreateWorldExportJob = Action("CreateWorldExportJob")
CreateWorldGenerationJob = Action("CreateWorldGenerationJob")
CreateWorldTemplate = Action("CreateWorldTemplate")
DeleteFleet = Action("DeleteFleet")
DeleteRobot = Action("DeleteRobot")
DeleteRobotApplication = Action("DeleteRobotApplication")
DeleteSimulationApplication = Action("DeleteSimulationApplication")
DeleteWorldTemplate = Action("DeleteWorldTemplate")
DeregisterRobot = Action("DeregisterRobot")
DescribeDeploymentJob = Action("DescribeDeploymentJob")
DescribeFleet = Action("DescribeFleet")
DescribeRobot = Action("DescribeRobot")
DescribeRobotApplication = Action("DescribeRobotApplication")
DescribeSimulationApplication = Action("DescribeSimulationApplication")
DescribeSimulationJob = Action("DescribeSimulationJob")
DescribeSimulationJobBatch = Action("DescribeSimulationJobBatch")
DescribeWorld = Action("DescribeWorld")
DescribeWorldExportJob = Action("DescribeWorldExportJob")
DescribeWorldGenerationJob = Action("DescribeWorldGenerationJob")
DescribeWorldTemplate = Action("DescribeWorldTemplate")
GetWorldTemplateBody = Action("GetWorldTemplateBody")
ListDeploymentJobs = Action("ListDeploymentJobs")
ListFleets = Action("ListFleets")
ListRobotApplications = Action("ListRobotApplications")
ListRobots = Action("ListRobots")
ListSimulationApplications = Action("ListSimulationApplications")
ListSimulationJobBatches = Action("ListSimulationJobBatches")
ListSimulationJobs = Action("ListSimulationJobs")
ListSupportedAvailabilityZones = Action("ListSupportedAvailabilityZones")
ListTagsForResource = Action("ListTagsForResource")
ListWorldExportJobs = Action("ListWorldExportJobs")
ListWorldGenerationJobs = Action("ListWorldGenerationJobs")
ListWorldTemplates = Action("ListWorldTemplates")
ListWorlds = Action("ListWorlds")
RegisterRobot = Action("RegisterRobot")
RestartSimulationJob = Action("RestartSimulationJob")
StartSimulationJobBatch = Action("StartSimulationJobBatch")
SyncDeploymentJob = Action("SyncDeploymentJob")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateRobotApplication = Action("UpdateRobotApplication")
UpdateRobotDeployment = Action("UpdateRobotDeployment")
UpdateSimulationApplication = Action("UpdateSimulationApplication")
UpdateWorldTemplate = Action("UpdateWorldTemplate")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Serverless Application Repository"
prefix = "serverlessrepo"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateApplication = Action("CreateApplication")
CreateApplicationVersion = Action("CreateApplicationVersion")
CreateCloudFormationChangeSet = Action("CreateCloudFormationChangeSet")
CreateCloudFormationTemplate = Action("CreateCloudFormationTemplate")
DeleteApplication = Action("DeleteApplication")
GetApplication = Action("GetApplication")
GetApplicationPolicy = Action("GetApplicationPolicy")
GetCloudFormationTemplate = Action("GetCloudFormationTemplate")
ListApplicationDependencies = Action("ListApplicationDependencies")
ListApplicationVersions = Action("ListApplicationVersions")
ListApplications = Action("ListApplications")
PutApplicationPolicy = Action("PutApplicationPolicy")
SearchApplications = Action("SearchApplications")
UnshareApplication = Action("UnshareApplication")
UpdateApplication = Action("UpdateApplication")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Migration Hub Strategy Recommendations"
prefix = "migrationhub-strategy"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


GetAntiPattern = Action("GetAntiPattern")
GetApplicationComponentDetails = Action("GetApplicationComponentDetails")
GetApplicationComponentStrategies = Action("GetApplicationComponentStrategies")
GetAssessment = Action("GetAssessment")
GetImportFileTask = Action("GetImportFileTask")
GetMessage = Action("GetMessage")
GetPortfolioPreferences = Action("GetPortfolioPreferences")
GetPortfolioSummary = Action("GetPortfolioSummary")
GetRecommendationReportDetails = Action("GetRecommendationReportDetails")
GetServerDetails = Action("GetServerDetails")
GetServerStrategies = Action("GetServerStrategies")
ListAntiPatterns = Action("ListAntiPatterns")
ListApplicationComponents = Action("ListApplicationComponents")
ListCollectors = Action("ListCollectors")
ListImportFileTask = Action("ListImportFileTask")
ListJarArtifacts = Action("ListJarArtifacts")
ListServers = Action("ListServers")
PutPortfolioPreferences = Action("PutPortfolioPreferences")
RegisterCollector = Action("RegisterCollector")
SendMessage = Action("SendMessage")
StartAssessment = Action("StartAssessment")
StartImportFileTask = Action("StartImportFileTask")
StartRecommendationReportGeneration = Action("StartRecommendationReportGeneration")
StopAssessment = Action("StopAssessment")
UpdateApplicationComponentConfig = Action("UpdateApplicationComponentConfig")
UpdateServerConfig = Action("UpdateServerConfig")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon Inspector"
prefix = "inspector"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AddAttributesToFindings = Action("AddAttributesToFindings")
CreateAssessmentTarget = Action("CreateAssessmentTarget")
CreateAssessmentTemplate = Action("CreateAssessmentTemplate")
CreateExclusionsPreview = Action("CreateExclusionsPreview")
CreateResourceGroup = Action("CreateResourceGroup")
DeleteAssessmentRun = Action("DeleteAssessmentRun")
DeleteAssessmentTarget = Action("DeleteAssessmentTarget")
DeleteAssessmentTemplate = Action("DeleteAssessmentTemplate")
DescribeAssessmentRuns = Action("DescribeAssessmentRuns")
DescribeAssessmentTargets = Action("DescribeAssessmentTargets")
DescribeAssessmentTemplates = Action("DescribeAssessmentTemplates")
DescribeCrossAccountAccessRole = Action("DescribeCrossAccountAccessRole")
DescribeExclusions = Action("DescribeExclusions")
DescribeFindings = Action("DescribeFindings")
DescribeResourceGroups = Action("DescribeResourceGroups")
DescribeRulesPackages = Action("DescribeRulesPackages")
GetAssessmentReport = Action("GetAssessmentReport")
GetExclusionsPreview = Action("GetExclusionsPreview")
GetTelemetryMetadata = Action("GetTelemetryMetadata")
ListAssessmentRunAgents = Action("ListAssessmentRunAgents")
ListAssessmentRuns = Action("ListAssessmentRuns")
ListAssessmentTargets = Action("ListAssessmentTargets")
ListAssessmentTemplates = Action("ListAssessmentTemplates")
ListEventSubscriptions = Action("ListEventSubscriptions")
ListExclusions = Action("ListExclusions")
ListFindings = Action("ListFindings")
ListRulesPackages = Action("ListRulesPackages")
ListTagsForResource = Action("ListTagsForResource")
PreviewAgents = Action("PreviewAgents")
RegisterCrossAccountAccessRole = Action("RegisterCrossAccountAccessRole")
RemoveAttributesFromFindings = Action("RemoveAttributesFromFindings")
SetTagsForResource = Action("SetTagsForResource")
StartAssessmentRun = Action("StartAssessmentRun")
StopAssessmentRun = Action("StopAssessmentRun")
SubscribeToEvent = Action("SubscribeToEvent")
UnsubscribeFromEvent = Action("UnsubscribeFromEvent")
UpdateAssessmentTarget = Action("UpdateAssessmentTarget")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon AppStream 2.0"
prefix = "appstream"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


AssociateApplicationFleet = Action("AssociateApplicationFleet")
AssociateApplicationToEntitlement = Action("AssociateApplicationToEntitlement")
AssociateApplicatonToEntitlement = Action("AssociateApplicatonToEntitlement")
AssociateFleet = Action("AssociateFleet")
BatchAssociateUserStack = Action("BatchAssociateUserStack")
BatchDisassociateUserStack = Action("BatchDisassociateUserStack")
CopyImage = Action("CopyImage")
CreateAppBlock = Action("CreateAppBlock")
CreateApplication = Action("CreateApplication")
CreateDirectoryConfig = Action("CreateDirectoryConfig")
CreateEntitlement = Action("CreateEntitlement")
CreateFleet = Action("CreateFleet")
CreateImageBuilder = Action("CreateImageBuilder")
CreateImageBuilderStreamingURL = Action("CreateImageBuilderStreamingURL")
CreateStack = Action("CreateStack")
CreateStreamingURL = Action("CreateStreamingURL")
CreateUpdatedImage = Action("CreateUpdatedImage")
CreateUsageReportSubscription = Action("CreateUsageReportSubscription")
CreateUser = Action("CreateUser")
DeleteAppBlock = Action("DeleteAppBlock")
DeleteApplication = Action("DeleteApplication")
DeleteDirectoryConfig = Action("DeleteDirectoryConfig")
DeleteEntitlement = Action("DeleteEntitlement")
DeleteFleet = Action("DeleteFleet")
DeleteImage = Action("DeleteImage")
DeleteImageBuilder = Action("DeleteImageBuilder")
DeleteImagePermissions = Action("DeleteImagePermissions")
DeleteStack = Action("DeleteStack")
DeleteUsageReportSubscription = Action("DeleteUsageReportSubscription")
DeleteUser = Action("DeleteUser")
DescribeAppBlocks = Action("DescribeAppBlocks")
DescribeApplicationFleetAssociations = Action("DescribeApplicationFleetAssociations")
DescribeApplications = Action("DescribeApplications")
DescribeDirectoryConfigs = Action("DescribeDirectoryConfigs")
DescribeEntitlements = Action("DescribeEntitlements")
DescribeFleets = Action("DescribeFleets")
DescribeImageBuilders = Action("DescribeImageBuilders")
DescribeImagePermissions = Action("DescribeImagePermissions")
DescribeImages = Action("DescribeImages")
DescribeSessions = Action("DescribeSessions")
DescribeStacks = Action("DescribeStacks")
DescribeUsageReportSubscriptions = Action("DescribeUsageReportSubscriptions")
DescribeUserStackAssociations = Action("DescribeUserStackAssociations")
DescribeUsers = Action("DescribeUsers")
DisableUser = Action("DisableUser")
DisassociateApplicationFleet = Action("DisassociateApplicationFleet")
DisassociateApplicationFromEntitlement = Action(
    "DisassociateApplicationFromEntitlement"
)
DisassociateApplicatonFromEntitlement = Action("DisassociateApplicatonFromEntitlement")
DisassociateFleet = Action("DisassociateFleet")
EnableUser = Action("EnableUser")
ExpireSession = Action("ExpireSession")
GetImageBuilders = Action("GetImageBuilders")
GetParametersForThemeAssetUpload = Action("GetParametersForThemeAssetUpload")
ListAssociatedFleets = Action("ListAssociatedFleets")
ListAssociatedStacks = Action("ListAssociatedStacks")
ListEntitledApplications = Action("ListEntitledApplications")
ListTagsForResource = Action("ListTagsForResource")
StartFleet = Action("StartFleet")
StartImageBuilder = Action("StartImageBuilder")
StopFleet = Action("StopFleet")
StopImageBuilder = Action("StopImageBuilder")
Stream = Action("Stream")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateApplication = Action("UpdateApplication")
UpdateDirectoryConfig = Action("UpdateDirectoryConfig")
UpdateEntitlement = Action("UpdateEntitlement")
UpdateFleet = Action("UpdateFleet")
UpdateImagePermissions = Action("UpdateImagePermissions")
UpdateStack = Action("UpdateStack")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon QLDB"
prefix = "qldb"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CancelJournalKinesisStream = Action("CancelJournalKinesisStream")
CreateLedger = Action("CreateLedger")
DeleteLedger = Action("DeleteLedger")
DescribeJournalKinesisStream = Action("DescribeJournalKinesisStream")
DescribeJournalS3Export = Action("DescribeJournalS3Export")
DescribeLedger = Action("DescribeLedger")
ExecuteStatement = Action("ExecuteStatement")
ExportJournalToS3 = Action("ExportJournalToS3")
GetBlock = Action("GetBlock")
GetDigest = Action("GetDigest")
GetRevision = Action("GetRevision")
InsertSampleData = Action("InsertSampleData")
ListJournalKinesisStreamsForLedger = Action("ListJournalKinesisStreamsForLedger")
ListJournalS3Exports = Action("ListJournalS3Exports")
ListJournalS3ExportsForLedger = Action("ListJournalS3ExportsForLedger")
ListLedgers = Action("ListLedgers")
ListTagsForResource = Action("ListTagsForResource")
PartiQLCreateIndex = Action("PartiQLCreateIndex")
PartiQLCreateTable = Action("PartiQLCreateTable")
PartiQLDelete = Action("PartiQLDelete")
PartiQLDropIndex = Action("PartiQLDropIndex")
PartiQLDropTable = Action("PartiQLDropTable")
PartiQLHistoryFunction = Action("PartiQLHistoryFunction")
PartiQLInsert = Action("PartiQLInsert")
PartiQLSelect = Action("PartiQLSelect")
PartiQLUndropTable = Action("PartiQLUndropTable")
PartiQLUpdate = Action("PartiQLUpdate")
SendCommand = Action("SendCommand")
ShowCatalog = Action("ShowCatalog")
StreamJournalToKinesis = Action("StreamJournalToKinesis")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateLedger = Action("UpdateLedger")
UpdateLedgerPermissionsMode = Action("UpdateLedgerPermissionsMode")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Amplify Admin"
prefix = "amplifybackend"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CloneBackend = Action("CloneBackend")
CreateBackend = Action("CreateBackend")
CreateBackendAPI = Action("CreateBackendAPI")
CreateBackendAuth = Action("CreateBackendAuth")
CreateBackendConfig = Action("CreateBackendConfig")
CreateBackendStorage = Action("CreateBackendStorage")
CreateToken = Action("CreateToken")
DeleteBackend = Action("DeleteBackend")
DeleteBackendAPI = Action("DeleteBackendAPI")
DeleteBackendAuth = Action("DeleteBackendAuth")
DeleteBackendStorage = Action("DeleteBackendStorage")
DeleteToken = Action("DeleteToken")
GenerateBackendAPIModels = Action("GenerateBackendAPIModels")
GetBackend = Action("GetBackend")
GetBackendAPI = Action("GetBackendAPI")
GetBackendAPIModels = Action("GetBackendAPIModels")
GetBackendAuth = Action("GetBackendAuth")
GetBackendJob = Action("GetBackendJob")
GetBackendStorage = Action("GetBackendStorage")
GetToken = Action("GetToken")
ImportBackendAuth = Action("ImportBackendAuth")
ImportBackendStorage = Action("ImportBackendStorage")
ListBackendJobs = Action("ListBackendJobs")
ListS3Buckets = Action("ListS3Buckets")
RemoveAllBackends = Action("RemoveAllBackends")
RemoveBackendConfig = Action("RemoveBackendConfig")
UpdateBackendAPI = Action("UpdateBackendAPI")
UpdateBackendAuth = Action("UpdateBackendAuth")
UpdateBackendConfig = Action("UpdateBackendConfig")
UpdateBackendJob = Action("UpdateBackendJob")
UpdateBackendStorage = Action("UpdateBackendStorage")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Data Pipeline"
prefix = "datapipeline"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


ActivatePipeline = Action("ActivatePipeline")
AddTags = Action("AddTags")
CreatePipeline = Action("CreatePipeline")
DeactivatePipeline = Action("DeactivatePipeline")
DeletePipeline = Action("DeletePipeline")
DescribeObjects = Action("DescribeObjects")
DescribePipelines = Action("DescribePipelines")
EvaluateExpression = Action("EvaluateExpression")
GetAccountLimits = Action("GetAccountLimits")
GetPipelineDefinition = Action("GetPipelineDefinition")
ListPipelines = Action("ListPipelines")
PollForTask = Action("PollForTask")
PutAccountLimits = Action("PutAccountLimits")
PutPipelineDefinition = Action("PutPipelineDefinition")
QueryObjects = Action("QueryObjects")
RemoveTags = Action("RemoveTags")
ReportTaskProgress = Action("ReportTaskProgress")
ReportTaskRunnerHeartbeat = Action("ReportTaskRunnerHeartbeat")
SetStatus = Action("SetStatus")
SetTaskStatus = Action("SetTaskStatus")
ValidatePipelineDefinition = Action("ValidatePipelineDefinition")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "AWS Outposts"
prefix = "outposts"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CancelOrder = Action("CancelOrder")
CreateOrder = Action("CreateOrder")
CreateOutpost = Action("CreateOutpost")
CreatePrivateConnectivityConfig = Action("CreatePrivateConnectivityConfig")
CreateSite = Action("CreateSite")
DeleteOutpost = Action("DeleteOutpost")
DeleteSite = Action("DeleteSite")
GetCatalogItem = Action("GetCatalogItem")
GetConnection = Action("GetConnection")
GetOrder = Action("GetOrder")
GetOutpost = Action("GetOutpost")
GetOutpostInstanceTypes = Action("GetOutpostInstanceTypes")
GetPrivateConnectivityConfig = Action("GetPrivateConnectivityConfig")
GetSite = Action("GetSite")
GetSiteAddress = Action("GetSiteAddress")
ListAssets = Action("ListAssets")
ListCatalogItems = Action("ListCatalogItems")
ListOrders = Action("ListOrders")
ListOutposts = Action("ListOutposts")
ListSites = Action("ListSites")
ListTagsForResource = Action("ListTagsForResource")
StartConnection = Action("StartConnection")
TagResource = Action("TagResource")
UntagResource = Action("UntagResource")
UpdateOutpost = Action("UpdateOutpost")
UpdateSite = Action("UpdateSite")
UpdateSiteAddress = Action("UpdateSiteAddress")
UpdateSiteRackPhysicalProperties = Action("UpdateSiteRackPhysicalProperties")



# Copyright (c) 2012-2021, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

from .aws import Action as BaseAction
from .aws import BaseARN

service_name = "Amazon AppFlow"
prefix = "appflow"


class Action(BaseAction):
    def __init__(self, action: str = None) -> None:
        super().__init__(prefix, action)


class ARN(BaseARN):
    def __init__(self, resource: str = "", region: str = "", account: str = "") -> None:
        super().__init__(
            service=prefix, resource=resource, region=region, account=account
        )


CreateConnectorProfile = Action("CreateConnectorProfile")
CreateFlow = Action("CreateFlow")
DeleteConnectorProfile = Action("DeleteConnectorProfile")
DeleteFlow = Action("DeleteFlow")
DescribeConnector = Action("DescribeConnector")
DescribeConnectorEntity = Action("DescribeConnectorEntity")
DescribeConnectorFields = Action("DescribeConnectorFields")
DescribeConnectorProfiles = Action("DescribeConnectorProfiles")
DescribeConnectors = Action("DescribeConnectors")
DescribeFlow = Action("DescribeFlow")
DescribeFlowExecution = Action("DescribeFlowExecution")
DescribeFlowExecutionRecords = Action("DescribeFlowExecutionRecords")
DescribeFlows = Action("DescribeFlows")
ListConnectorEntities = Action("ListConnectorEntities")
ListConnectorFields = Action("ListConnectorFields")
ListConnectors = Action("ListConnectors")
ListFlows = Action("ListFlows")
ListTagsForResource = Action("ListTagsForResource")
RegisterConnector = Action("RegisterConnector")
RunFlow = Action("RunFlow")
StartFlow = Action("StartFlow")
StopFlow = Action("StopFlow")
TagResource = Action("TagResource")
UnRegisterConnector = Action("UnRegisterConnector")
UntagResource = Action("UntagResource")
UpdateConnectorProfile = Action("UpdateConnectorProfile")
UpdateFlow = Action("UpdateFlow")
UseConnectorProfile = Action("UseConnectorProfile")
